/*******************************************************************************
* File Name: PD_USBFS.h
* Version 2.80
*
* Description:
*  Header File for the USBFS component. Contains prototypes and constant values.
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_PD_USBFS_H)
#define CY_USBFS_PD_USBFS_H

#include "cytypes.h"
#include "cydevice_trm.h"
#include "cyfitter.h"
#include "CyLib.h"

/*  User supplied definitions. */
/* `#START USER_DEFINITIONS` Place your declaration here */

/* `#END` */


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component USBFS_v2_80 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*  Memory Type Definitions
***************************************/

/* Renamed Type Definitions for backward compatibility.
*  Should not be used in new designs.
*/
#define PD_USBFS_CODE CYCODE
#define PD_USBFS_FAR CYFAR
#if defined(__C51__) || defined(__CX51__)
    #define PD_USBFS_DATA data
    #define PD_USBFS_XDATA xdata
#else
    #define PD_USBFS_DATA
    #define PD_USBFS_XDATA
#endif /*  __C51__ */
#define PD_USBFS_NULL       NULL


/***************************************
* Enumerated Types and Parameters
***************************************/

#define PD_USBFS__EP_MANUAL 0
#define PD_USBFS__EP_DMAMANUAL 1
#define PD_USBFS__EP_DMAAUTO 2

#define PD_USBFS__MA_STATIC 0
#define PD_USBFS__MA_DYNAMIC 1



/***************************************
*    Initial Parameter Constants
***************************************/

#define PD_USBFS_NUM_DEVICES   (1u)
#define PD_USBFS_ENABLE_DESCRIPTOR_STRINGS   
#define PD_USBFS_ENABLE_SN_STRING   
#define PD_USBFS_ENABLE_STRINGS   
#define PD_USBFS_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_IN_BUF_SIZE   (65u)
#define PD_USBFS_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_NUM_IN_RPTS   (1u)
#define PD_USBFS_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_OUT_BUF_SIZE   (65u)
#define PD_USBFS_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_NUM_OUT_RPTS   (1u)
#define PD_USBFS_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_COUNT   (1u)
#define PD_USBFS_ENABLE_HID_CLASS   
#define PD_USBFS_HID_RPT_1_SIZE_LSB   (0x24u)
#define PD_USBFS_HID_RPT_1_SIZE_MSB   (0x00u)
#define PD_USBFS_HID_RPT_2_SIZE_LSB   (0x24u)
#define PD_USBFS_HID_RPT_2_SIZE_MSB   (0x00u)
#define PD_USBFS_MAX_REPORTID_NUMBER   (0u)

#define PD_USBFS_MON_VBUS                       (0u)
#define PD_USBFS_EXTERN_VBUS                    (0u)
#define PD_USBFS_EXTERN_VND                     (0u)
#define PD_USBFS_EXTERN_CLS                     (0u)
#define PD_USBFS_MAX_INTERFACES_NUMBER          (1u)
#define PD_USBFS_EP0_ISR_REMOVE                 (0u)
#define PD_USBFS_EP1_ISR_REMOVE                 (0u)
#define PD_USBFS_EP2_ISR_REMOVE                 (0u)
#define PD_USBFS_EP3_ISR_REMOVE                 (1u)
#define PD_USBFS_EP4_ISR_REMOVE                 (1u)
#define PD_USBFS_EP5_ISR_REMOVE                 (1u)
#define PD_USBFS_EP6_ISR_REMOVE                 (1u)
#define PD_USBFS_EP7_ISR_REMOVE                 (1u)
#define PD_USBFS_EP8_ISR_REMOVE                 (1u)
#define PD_USBFS_EP_MM                          (0u)
#define PD_USBFS_EP_MA                          (0u)
#define PD_USBFS_EP_DMA_AUTO_OPT                (0u)
#define PD_USBFS_DMA1_REMOVE                    (1u)
#define PD_USBFS_DMA2_REMOVE                    (1u)
#define PD_USBFS_DMA3_REMOVE                    (1u)
#define PD_USBFS_DMA4_REMOVE                    (1u)
#define PD_USBFS_DMA5_REMOVE                    (1u)
#define PD_USBFS_DMA6_REMOVE                    (1u)
#define PD_USBFS_DMA7_REMOVE                    (1u)
#define PD_USBFS_DMA8_REMOVE                    (1u)
#define PD_USBFS_SOF_ISR_REMOVE                 (0u)
#define PD_USBFS_ARB_ISR_REMOVE                 (0u)
#define PD_USBFS_DP_ISR_REMOVE                  (0u)
#define PD_USBFS_ENABLE_CDC_CLASS_API           (1u)
#define PD_USBFS_ENABLE_MIDI_API                (1u)
#define PD_USBFS_MIDI_EXT_MODE                  (0u)


/***************************************
*    Data Struct Definition
***************************************/

typedef struct
{
    uint8  attrib;
    uint8  apiEpState;
    uint8  hwEpState;
    uint8  epToggle;
    uint8  addr;
    uint8  epMode;
    uint16 buffOffset;
    uint16 bufferSize;
    uint8  interface;
} T_PD_USBFS_EP_CTL_BLOCK;

typedef struct
{
    uint8  interface;
    uint8  altSetting;
    uint8  addr;
    uint8  attributes;
    uint16 bufferSize;
    uint8  bMisc;
} T_PD_USBFS_EP_SETTINGS_BLOCK;

typedef struct
{
    uint8  status;
    uint16 length;
} T_PD_USBFS_XFER_STATUS_BLOCK;

typedef struct
{
    uint16  count;
    volatile uint8 *pData;
    T_PD_USBFS_XFER_STATUS_BLOCK *pStatusBlock;
} T_PD_USBFS_TD;


typedef struct
{
    uint8   c;
    const void *p_list;
} T_PD_USBFS_LUT;

/* Resume/Suspend API Support */
typedef struct
{
    uint8 enableState;
    uint8 mode;
} PD_USBFS_BACKUP_STRUCT;


/* Renamed structure fields for backward compatibility.
*  Should not be used in new designs.
*/
#define wBuffOffset         buffOffset
#define wBufferSize         bufferSize
#define bStatus             status
#define wLength             length
#define wCount              count

/* Renamed global variable for backward compatibility.
*  Should not be used in new designs.
*/
#define CurrentTD           PD_USBFS_currentTD


/***************************************
*       Function Prototypes
***************************************/

void   PD_USBFS_Start(uint8 device, uint8 mode) ;
void   PD_USBFS_Init(void) ;
void   PD_USBFS_InitComponent(uint8 device, uint8 mode) ;
void   PD_USBFS_Stop(void) ;
uint8  PD_USBFS_CheckActivity(void) ;
uint8  PD_USBFS_GetConfiguration(void) ;
uint8  PD_USBFS_IsConfigurationChanged(void) ;
uint8  PD_USBFS_GetInterfaceSetting(uint8 interfaceNumber)
                                                        ;
uint8  PD_USBFS_GetEPState(uint8 epNumber) ;
uint16 PD_USBFS_GetEPCount(uint8 epNumber) ;
void   PD_USBFS_LoadInEP(uint8 epNumber, const uint8 pData[], uint16 length)
                                                                    ;
uint16 PD_USBFS_ReadOutEP(uint8 epNumber, uint8 pData[], uint16 length)
                                                                    ;
void   PD_USBFS_EnableOutEP(uint8 epNumber) ;
void   PD_USBFS_DisableOutEP(uint8 epNumber) ;
void   PD_USBFS_Force(uint8 bState) ;
uint8  PD_USBFS_GetEPAckState(uint8 epNumber) ;
void   PD_USBFS_SetPowerStatus(uint8 powerStatus) ;
uint8  PD_USBFS_RWUEnabled(void) ;
void   PD_USBFS_TerminateEP(uint8 ep) ;

void   PD_USBFS_Suspend(void) ;
void   PD_USBFS_Resume(void) ;

#if defined(PD_USBFS_ENABLE_FWSN_STRING)
    void   PD_USBFS_SerialNumString(uint8 snString[]) ;
#endif  /* PD_USBFS_ENABLE_FWSN_STRING */
#if (PD_USBFS_MON_VBUS == 1u)
    uint8  PD_USBFS_VBusPresent(void) ;
#endif /*  PD_USBFS_MON_VBUS */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PD_USBFS) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

    void PD_USBFS_CyBtldrCommStart(void) ;
    void PD_USBFS_CyBtldrCommStop(void) ;
    void PD_USBFS_CyBtldrCommReset(void) ;
    cystatus PD_USBFS_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 *count, uint8 timeOut) CYSMALL
                                                        ;
    cystatus PD_USBFS_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 *count, uint8 timeOut) CYSMALL
                                                        ;

    #define PD_USBFS_BTLDR_OUT_EP      (0x01u)
    #define PD_USBFS_BTLDR_IN_EP       (0x02u)

    #define PD_USBFS_BTLDR_SIZEOF_WRITE_BUFFER  (64u)   /* EP 1 OUT */
    #define PD_USBFS_BTLDR_SIZEOF_READ_BUFFER   (64u)   /* EP 2 IN  */
    #define PD_USBFS_BTLDR_MAX_PACKET_SIZE      PD_USBFS_BTLDR_SIZEOF_WRITE_BUFFER

    #define PD_USBFS_BTLDR_WAIT_1_MS            (1u)    /* Time Out quantity equal 1mS */

    /* These defines active if used USBFS interface as an
    *  IO Component for bootloading. When Custom_Interface selected
    *  in Bootloder configuration as the IO Component, user must
    *  provide these functions.
    */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PD_USBFS)
        #define CyBtldrCommStart        PD_USBFS_CyBtldrCommStart
        #define CyBtldrCommStop         PD_USBFS_CyBtldrCommStop
        #define CyBtldrCommReset        PD_USBFS_CyBtldrCommReset
        #define CyBtldrCommWrite        PD_USBFS_CyBtldrCommWrite
        #define CyBtldrCommRead         PD_USBFS_CyBtldrCommRead
    #endif  /*End   CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PD_USBFS */

#endif /*  CYDEV_BOOTLOADER_IO_COMP  */

#if(PD_USBFS_EP_MM != PD_USBFS__EP_MANUAL)
    void PD_USBFS_InitEP_DMA(uint8 epNumber, const uint8* pData)
                                                    ;
    void PD_USBFS_Stop_DMA(uint8 epNumber) ;
#endif /*  PD_USBFS_EP_MM != PD_USBFS__EP_MANUAL) */

#if defined(PD_USBFS_ENABLE_MIDI_STREAMING) && (PD_USBFS_ENABLE_MIDI_API != 0u)
    void PD_USBFS_MIDI_EP_Init(void) ;

    #if (PD_USBFS_MIDI_IN_BUFF_SIZE > 0)
        void PD_USBFS_MIDI_IN_Service(void) ;
        uint8 PD_USBFS_PutUsbMidiIn(uint8 ic, const uint8 midiMsg[], uint8 cable)
                                                                ;
    #endif /* PD_USBFS_MIDI_IN_BUFF_SIZE > 0 */

    #if (PD_USBFS_MIDI_OUT_BUFF_SIZE > 0)
        void PD_USBFS_MIDI_OUT_EP_Service(void) ;
    #endif /* PD_USBFS_MIDI_OUT_BUFF_SIZE > 0 */

#endif /*  PD_USBFS_ENABLE_MIDI_API != 0u */

/* Renamed Functions for backward compatibility.
*  Should not be used in new designs.
*/

#define PD_USBFS_bCheckActivity             PD_USBFS_CheckActivity
#define PD_USBFS_bGetConfiguration          PD_USBFS_GetConfiguration
#define PD_USBFS_bGetInterfaceSetting       PD_USBFS_GetInterfaceSetting
#define PD_USBFS_bGetEPState                PD_USBFS_GetEPState
#define PD_USBFS_wGetEPCount                PD_USBFS_GetEPCount
#define PD_USBFS_bGetEPAckState             PD_USBFS_GetEPAckState
#define PD_USBFS_bRWUEnabled                PD_USBFS_RWUEnabled
#define PD_USBFS_bVBusPresent               PD_USBFS_VBusPresent

#define PD_USBFS_bConfiguration             PD_USBFS_configuration
#define PD_USBFS_bInterfaceSetting          PD_USBFS_interfaceSetting
#define PD_USBFS_bDeviceAddress             PD_USBFS_deviceAddress
#define PD_USBFS_bDeviceStatus              PD_USBFS_deviceStatus
#define PD_USBFS_bDevice                    PD_USBFS_device
#define PD_USBFS_bTransferState             PD_USBFS_transferState
#define PD_USBFS_bLastPacketSize            PD_USBFS_lastPacketSize

#define PD_USBFS_LoadEP                     PD_USBFS_LoadInEP
#define PD_USBFS_LoadInISOCEP               PD_USBFS_LoadInEP
#define PD_USBFS_EnableOutISOCEP            PD_USBFS_EnableOutEP

#define PD_USBFS_SetVector                  CyIntSetVector
#define PD_USBFS_SetPriority                CyIntSetPriority
#define PD_USBFS_EnableInt                  CyIntEnable


/***************************************
*          API Constants
***************************************/

#define PD_USBFS_EP0                        (0u)
#define PD_USBFS_EP1                        (1u)
#define PD_USBFS_EP2                        (2u)
#define PD_USBFS_EP3                        (3u)
#define PD_USBFS_EP4                        (4u)
#define PD_USBFS_EP5                        (5u)
#define PD_USBFS_EP6                        (6u)
#define PD_USBFS_EP7                        (7u)
#define PD_USBFS_EP8                        (8u)
#define PD_USBFS_MAX_EP                     (9u)

#define PD_USBFS_TRUE                       (1u)
#define PD_USBFS_FALSE                      (0u)

#define PD_USBFS_NO_EVENT_ALLOWED           (2u)
#define PD_USBFS_EVENT_PENDING              (1u)
#define PD_USBFS_NO_EVENT_PENDING           (0u)

#define PD_USBFS_IN_BUFFER_FULL             PD_USBFS_NO_EVENT_PENDING
#define PD_USBFS_IN_BUFFER_EMPTY            PD_USBFS_EVENT_PENDING
#define PD_USBFS_OUT_BUFFER_FULL            PD_USBFS_EVENT_PENDING
#define PD_USBFS_OUT_BUFFER_EMPTY           PD_USBFS_NO_EVENT_PENDING

#define PD_USBFS_FORCE_J                    (0xA0u)
#define PD_USBFS_FORCE_K                    (0x80u)
#define PD_USBFS_FORCE_SE0                  (0xC0u)
#define PD_USBFS_FORCE_NONE                 (0x00u)

#define PD_USBFS_IDLE_TIMER_RUNNING         (0x02u)
#define PD_USBFS_IDLE_TIMER_EXPIRED         (0x01u)
#define PD_USBFS_IDLE_TIMER_INDEFINITE      (0x00u)

#define PD_USBFS_DEVICE_STATUS_BUS_POWERED  (0x00u)
#define PD_USBFS_DEVICE_STATUS_SELF_POWERED (0x01u)

#define PD_USBFS_3V_OPERATION               (0x00u)
#define PD_USBFS_5V_OPERATION               (0x01u)
#define PD_USBFS_DWR_VDDD_OPERATION         (0x02u)

#define PD_USBFS_MODE_DISABLE               (0x00u)
#define PD_USBFS_MODE_NAK_IN_OUT            (0x01u)
#define PD_USBFS_MODE_STATUS_OUT_ONLY       (0x02u)
#define PD_USBFS_MODE_STALL_IN_OUT          (0x03u)
#define PD_USBFS_MODE_RESERVED_0100         (0x04u)
#define PD_USBFS_MODE_ISO_OUT               (0x05u)
#define PD_USBFS_MODE_STATUS_IN_ONLY        (0x06u)
#define PD_USBFS_MODE_ISO_IN                (0x07u)
#define PD_USBFS_MODE_NAK_OUT               (0x08u)
#define PD_USBFS_MODE_ACK_OUT               (0x09u)
#define PD_USBFS_MODE_RESERVED_1010         (0x0Au)
#define PD_USBFS_MODE_ACK_OUT_STATUS_IN     (0x0Bu)
#define PD_USBFS_MODE_NAK_IN                (0x0Cu)
#define PD_USBFS_MODE_ACK_IN                (0x0Du)
#define PD_USBFS_MODE_RESERVED_1110         (0x0Eu)
#define PD_USBFS_MODE_ACK_IN_STATUS_OUT     (0x0Fu)
#define PD_USBFS_MODE_MASK                  (0x0Fu)
#define PD_USBFS_MODE_STALL_DATA_EP         (0x80u)

#define PD_USBFS_MODE_ACKD                  (0x10u)
#define PD_USBFS_MODE_OUT_RCVD              (0x20u)
#define PD_USBFS_MODE_IN_RCVD               (0x40u)
#define PD_USBFS_MODE_SETUP_RCVD            (0x80u)

#define PD_USBFS_RQST_TYPE_MASK             (0x60u)
#define PD_USBFS_RQST_TYPE_STD              (0x00u)
#define PD_USBFS_RQST_TYPE_CLS              (0x20u)
#define PD_USBFS_RQST_TYPE_VND              (0x40u)
#define PD_USBFS_RQST_DIR_MASK              (0x80u)
#define PD_USBFS_RQST_DIR_D2H               (0x80u)
#define PD_USBFS_RQST_DIR_H2D               (0x00u)
#define PD_USBFS_RQST_RCPT_MASK             (0x03u)
#define PD_USBFS_RQST_RCPT_DEV              (0x00u)
#define PD_USBFS_RQST_RCPT_IFC              (0x01u)
#define PD_USBFS_RQST_RCPT_EP               (0x02u)
#define PD_USBFS_RQST_RCPT_OTHER            (0x03u)

/* USB Class Codes */
#define PD_USBFS_CLASS_DEVICE               (0x00u)     /* Use class code info from Interface Descriptors */
#define PD_USBFS_CLASS_AUDIO                (0x01u)     /* Audio device */
#define PD_USBFS_CLASS_CDC                  (0x02u)     /* Communication device class */
#define PD_USBFS_CLASS_HID                  (0x03u)     /* Human Interface Device */
#define PD_USBFS_CLASS_PDC                  (0x05u)     /* Physical device class */
#define PD_USBFS_CLASS_IMAGE                (0x06u)     /* Still Imaging device */
#define PD_USBFS_CLASS_PRINTER              (0x07u)     /* Printer device  */
#define PD_USBFS_CLASS_MSD                  (0x08u)     /* Mass Storage device  */
#define PD_USBFS_CLASS_HUB                  (0x09u)     /* Full/Hi speed Hub */
#define PD_USBFS_CLASS_CDC_DATA             (0x0Au)     /* CDC data device */
#define PD_USBFS_CLASS_SMART_CARD           (0x0Bu)     /* Smart Card device */
#define PD_USBFS_CLASS_CSD                  (0x0Du)     /* Content Security device */
#define PD_USBFS_CLASS_VIDEO                (0x0Eu)     /* Video device */
#define PD_USBFS_CLASS_PHD                  (0x0Fu)     /* Personal Healthcare device */
#define PD_USBFS_CLASS_WIRELESSD            (0xDCu)     /* Wireless Controller */
#define PD_USBFS_CLASS_MIS                  (0xE0u)     /* Miscellaneous */
#define PD_USBFS_CLASS_APP                  (0xEFu)     /* Application Specific */
#define PD_USBFS_CLASS_VENDOR               (0xFFu)     /* Vendor specific */


/* Standard Request Types (Table 9-4) */
#define PD_USBFS_GET_STATUS                 (0x00u)
#define PD_USBFS_CLEAR_FEATURE              (0x01u)
#define PD_USBFS_SET_FEATURE                (0x03u)
#define PD_USBFS_SET_ADDRESS                (0x05u)
#define PD_USBFS_GET_DESCRIPTOR             (0x06u)
#define PD_USBFS_SET_DESCRIPTOR             (0x07u)
#define PD_USBFS_GET_CONFIGURATION          (0x08u)
#define PD_USBFS_SET_CONFIGURATION          (0x09u)
#define PD_USBFS_GET_INTERFACE              (0x0Au)
#define PD_USBFS_SET_INTERFACE              (0x0Bu)
#define PD_USBFS_SYNCH_FRAME                (0x0Cu)

/* Vendor Specific Request Types */
/* Request for Microsoft OS String Descriptor */
#define PD_USBFS_GET_EXTENDED_CONFIG_DESCRIPTOR (0x01u)

/* Descriptor Types (Table 9-5) */
#define PD_USBFS_DESCR_DEVICE                   (1u)
#define PD_USBFS_DESCR_CONFIG                   (2u)
#define PD_USBFS_DESCR_STRING                   (3u)
#define PD_USBFS_DESCR_INTERFACE                (4u)
#define PD_USBFS_DESCR_ENDPOINT                 (5u)
#define PD_USBFS_DESCR_DEVICE_QUALIFIER         (6u)
#define PD_USBFS_DESCR_OTHER_SPEED              (7u)
#define PD_USBFS_DESCR_INTERFACE_POWER          (8u)

/* Device Descriptor Defines */
#define PD_USBFS_DEVICE_DESCR_LENGTH            (18u)
#define PD_USBFS_DEVICE_DESCR_SN_SHIFT          (16u)

/* Config Descriptor Shifts and Masks */
#define PD_USBFS_CONFIG_DESCR_LENGTH                (0u)
#define PD_USBFS_CONFIG_DESCR_TYPE                  (1u)
#define PD_USBFS_CONFIG_DESCR_TOTAL_LENGTH_LOW      (2u)
#define PD_USBFS_CONFIG_DESCR_TOTAL_LENGTH_HI       (3u)
#define PD_USBFS_CONFIG_DESCR_NUM_INTERFACES        (4u)
#define PD_USBFS_CONFIG_DESCR_CONFIG_VALUE          (5u)
#define PD_USBFS_CONFIG_DESCR_CONFIGURATION         (6u)
#define PD_USBFS_CONFIG_DESCR_ATTRIB                (7u)
#define PD_USBFS_CONFIG_DESCR_ATTRIB_SELF_POWERED   (0x40u)
#define PD_USBFS_CONFIG_DESCR_ATTRIB_RWU_EN         (0x20u)

/* Feature Selectors (Table 9-6) */
#define PD_USBFS_DEVICE_REMOTE_WAKEUP           (0x01u)
#define PD_USBFS_ENDPOINT_HALT                  (0x00u)
#define PD_USBFS_TEST_MODE                      (0x02u)

/* USB Device Status (Figure 9-4) */
#define PD_USBFS_DEVICE_STATUS_BUS_POWERED      (0x00u)
#define PD_USBFS_DEVICE_STATUS_SELF_POWERED     (0x01u)
#define PD_USBFS_DEVICE_STATUS_REMOTE_WAKEUP    (0x02u)

/* USB Endpoint Status (Figure 9-4) */
#define PD_USBFS_ENDPOINT_STATUS_HALT           (0x01u)

/* USB Endpoint Directions */
#define PD_USBFS_DIR_IN                         (0x80u)
#define PD_USBFS_DIR_OUT                        (0x00u)
#define PD_USBFS_DIR_UNUSED                     (0x7Fu)

/* USB Endpoint Attributes */
#define PD_USBFS_EP_TYPE_CTRL                   (0x00u)
#define PD_USBFS_EP_TYPE_ISOC                   (0x01u)
#define PD_USBFS_EP_TYPE_BULK                   (0x02u)
#define PD_USBFS_EP_TYPE_INT                    (0x03u)
#define PD_USBFS_EP_TYPE_MASK                   (0x03u)

#define PD_USBFS_EP_SYNC_TYPE_NO_SYNC           (0x00u)
#define PD_USBFS_EP_SYNC_TYPE_ASYNC             (0x04u)
#define PD_USBFS_EP_SYNC_TYPE_ADAPTIVE          (0x08u)
#define PD_USBFS_EP_SYNC_TYPE_SYNCHRONOUS       (0x0Cu)
#define PD_USBFS_EP_SYNC_TYPE_MASK              (0x0Cu)

#define PD_USBFS_EP_USAGE_TYPE_DATA             (0x00u)
#define PD_USBFS_EP_USAGE_TYPE_FEEDBACK         (0x10u)
#define PD_USBFS_EP_USAGE_TYPE_IMPLICIT         (0x20u)
#define PD_USBFS_EP_USAGE_TYPE_RESERVED         (0x30u)
#define PD_USBFS_EP_USAGE_TYPE_MASK             (0x30u)

/* point Status defines */
#define PD_USBFS_EP_STATUS_LENGTH               (0x02u)

/* point Device defines */
#define PD_USBFS_DEVICE_STATUS_LENGTH           (0x02u)

#define PD_USBFS_STATUS_LENGTH_MAX \
                 ( (PD_USBFS_EP_STATUS_LENGTH > PD_USBFS_DEVICE_STATUS_LENGTH) ? \
                    PD_USBFS_EP_STATUS_LENGTH : PD_USBFS_DEVICE_STATUS_LENGTH )
/* Transfer Completion Notification */
#define PD_USBFS_XFER_IDLE                      (0x00u)
#define PD_USBFS_XFER_STATUS_ACK                (0x01u)
#define PD_USBFS_XFER_PREMATURE                 (0x02u)
#define PD_USBFS_XFER_ERROR                     (0x03u)

/* Driver State defines */
#define PD_USBFS_TRANS_STATE_IDLE               (0x00u)
#define PD_USBFS_TRANS_STATE_CONTROL_READ       (0x02u)
#define PD_USBFS_TRANS_STATE_CONTROL_WRITE      (0x04u)
#define PD_USBFS_TRANS_STATE_NO_DATA_CONTROL    (0x06u)

/* String Descriptor defines */
#define PD_USBFS_STRING_MSOS                    (0xEEu)
#define PD_USBFS_MSOS_DESCRIPTOR_LENGTH         (18u)
#define PD_USBFS_MSOS_CONF_DESCR_LENGTH         (40u)

#if(PD_USBFS_EP_MM == PD_USBFS__EP_DMAMANUAL)
    /* DMA manual mode defines */
    #define PD_USBFS_DMA_BYTES_PER_BURST        (0u)
    #define PD_USBFS_DMA_REQUEST_PER_BURST      (0u)
#endif /*  PD_USBFS_EP_MM == PD_USBFS__EP_DMAMANUAL */
#if(PD_USBFS_EP_MM == PD_USBFS__EP_DMAAUTO)
    /* DMA automatic mode defines */
    #define PD_USBFS_DMA_BYTES_PER_BURST        (32u)
    #define PD_USBFS_DMA_BYTES_REPEAT           (2u)
    /* BUF_SIZE-BYTES_PER_BURST examples: 55-32 bytes  44-16 bytes 33-8 bytes 22-4 bytes 11-2 bytes */
    #define PD_USBFS_DMA_BUF_SIZE               (0x55u)
    #define PD_USBFS_DMA_REQUEST_PER_BURST      (1u)

    #if(PD_USBFS_DMA1_REMOVE == 0u)
        #define PD_USBFS_ep1_TD_TERMOUT_EN      PD_USBFS_ep1__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep1_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA1_REMOVE == 0u */
    #if(PD_USBFS_DMA2_REMOVE == 0u)
        #define PD_USBFS_ep2_TD_TERMOUT_EN      PD_USBFS_ep2__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep2_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA2_REMOVE == 0u */
    #if(PD_USBFS_DMA3_REMOVE == 0u)
        #define PD_USBFS_ep3_TD_TERMOUT_EN      PD_USBFS_ep3__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep3_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA3_REMOVE == 0u */
    #if(PD_USBFS_DMA4_REMOVE == 0u)
        #define PD_USBFS_ep4_TD_TERMOUT_EN      PD_USBFS_ep4__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep4_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA4_REMOVE == 0u */
    #if(PD_USBFS_DMA5_REMOVE == 0u)
        #define PD_USBFS_ep5_TD_TERMOUT_EN      PD_USBFS_ep5__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep5_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA5_REMOVE == 0u */
    #if(PD_USBFS_DMA6_REMOVE == 0u)
        #define PD_USBFS_ep6_TD_TERMOUT_EN      PD_USBFS_ep6__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep6_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA6_REMOVE == 0u */
    #if(PD_USBFS_DMA7_REMOVE == 0u)
        #define PD_USBFS_ep7_TD_TERMOUT_EN      PD_USBFS_ep7__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep7_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA7_REMOVE == 0u */
    #if(PD_USBFS_DMA8_REMOVE == 0u)
        #define PD_USBFS_ep8_TD_TERMOUT_EN      PD_USBFS_ep8__TD_TERMOUT_EN
    #else
        #define PD_USBFS_ep8_TD_TERMOUT_EN      (0u)
    #endif /* PD_USBFS_DMA8_REMOVE == 0u */

    #define     PD_USBFS_EP17_SR_MASK           (0x7fu)
    #define     PD_USBFS_EP8_SR_MASK            (0x03u)

#endif /*  PD_USBFS_EP_MM == PD_USBFS__EP_DMAAUTO */

/* DIE ID string descriptor defines */
#if defined(PD_USBFS_ENABLE_IDSN_STRING)
    #define PD_USBFS_IDSN_DESCR_LENGTH          (0x22u)
#endif /* PD_USBFS_ENABLE_IDSN_STRING */


/***************************************
* External data references
***************************************/

extern uint8 PD_USBFS_initVar;
extern volatile uint8 PD_USBFS_device;
extern volatile uint8 PD_USBFS_transferState;
extern volatile uint8 PD_USBFS_configuration;
extern volatile uint8 PD_USBFS_configurationChanged;
extern volatile uint8 PD_USBFS_deviceStatus;

/* HID Variables */
#if defined(PD_USBFS_ENABLE_HID_CLASS)
    extern volatile uint8 PD_USBFS_hidProtocol[PD_USBFS_MAX_INTERFACES_NUMBER];
    extern volatile uint8 PD_USBFS_hidIdleRate[PD_USBFS_MAX_INTERFACES_NUMBER];
    extern volatile uint8 PD_USBFS_hidIdleTimer[PD_USBFS_MAX_INTERFACES_NUMBER];
#endif /* PD_USBFS_ENABLE_HID_CLASS */


/***************************************
*              Registers
***************************************/

#define PD_USBFS_ARB_CFG_PTR        (  (reg8 *) PD_USBFS_USB__ARB_CFG)
#define PD_USBFS_ARB_CFG_REG        (* (reg8 *) PD_USBFS_USB__ARB_CFG)

#define PD_USBFS_ARB_EP1_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP1_CFG)
#define PD_USBFS_ARB_EP1_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP1_CFG)
#define PD_USBFS_ARB_EP1_CFG_IND    PD_USBFS_USB__ARB_EP1_CFG
#define PD_USBFS_ARB_EP1_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP1_INT_EN)
#define PD_USBFS_ARB_EP1_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP1_INT_EN)
#define PD_USBFS_ARB_EP1_INT_EN_IND PD_USBFS_USB__ARB_EP1_INT_EN
#define PD_USBFS_ARB_EP1_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP1_SR)
#define PD_USBFS_ARB_EP1_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP1_SR)
#define PD_USBFS_ARB_EP1_SR_IND     PD_USBFS_USB__ARB_EP1_SR

#define PD_USBFS_ARB_EP2_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP2_CFG)
#define PD_USBFS_ARB_EP2_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP2_CFG)
#define PD_USBFS_ARB_EP2_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP2_INT_EN)
#define PD_USBFS_ARB_EP2_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP2_INT_EN)
#define PD_USBFS_ARB_EP2_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP2_SR)
#define PD_USBFS_ARB_EP2_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP2_SR)

#define PD_USBFS_ARB_EP3_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP3_CFG)
#define PD_USBFS_ARB_EP3_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP3_CFG)
#define PD_USBFS_ARB_EP3_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP3_INT_EN)
#define PD_USBFS_ARB_EP3_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP3_INT_EN)
#define PD_USBFS_ARB_EP3_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP3_SR)
#define PD_USBFS_ARB_EP3_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP3_SR)

#define PD_USBFS_ARB_EP4_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP4_CFG)
#define PD_USBFS_ARB_EP4_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP4_CFG)
#define PD_USBFS_ARB_EP4_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP4_INT_EN)
#define PD_USBFS_ARB_EP4_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP4_INT_EN)
#define PD_USBFS_ARB_EP4_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP4_SR)
#define PD_USBFS_ARB_EP4_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP4_SR)

#define PD_USBFS_ARB_EP5_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP5_CFG)
#define PD_USBFS_ARB_EP5_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP5_CFG)
#define PD_USBFS_ARB_EP5_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP5_INT_EN)
#define PD_USBFS_ARB_EP5_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP5_INT_EN)
#define PD_USBFS_ARB_EP5_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP5_SR)
#define PD_USBFS_ARB_EP5_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP5_SR)

#define PD_USBFS_ARB_EP6_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP6_CFG)
#define PD_USBFS_ARB_EP6_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP6_CFG)
#define PD_USBFS_ARB_EP6_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP6_INT_EN)
#define PD_USBFS_ARB_EP6_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP6_INT_EN)
#define PD_USBFS_ARB_EP6_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP6_SR)
#define PD_USBFS_ARB_EP6_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP6_SR)

#define PD_USBFS_ARB_EP7_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP7_CFG)
#define PD_USBFS_ARB_EP7_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP7_CFG)
#define PD_USBFS_ARB_EP7_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP7_INT_EN)
#define PD_USBFS_ARB_EP7_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP7_INT_EN)
#define PD_USBFS_ARB_EP7_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP7_SR)
#define PD_USBFS_ARB_EP7_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP7_SR)

#define PD_USBFS_ARB_EP8_CFG_PTR    (  (reg8 *) PD_USBFS_USB__ARB_EP8_CFG)
#define PD_USBFS_ARB_EP8_CFG_REG    (* (reg8 *) PD_USBFS_USB__ARB_EP8_CFG)
#define PD_USBFS_ARB_EP8_INT_EN_PTR (  (reg8 *) PD_USBFS_USB__ARB_EP8_INT_EN)
#define PD_USBFS_ARB_EP8_INT_EN_REG (* (reg8 *) PD_USBFS_USB__ARB_EP8_INT_EN)
#define PD_USBFS_ARB_EP8_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_EP8_SR)
#define PD_USBFS_ARB_EP8_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_EP8_SR)

#define PD_USBFS_ARB_INT_EN_PTR     (  (reg8 *) PD_USBFS_USB__ARB_INT_EN)
#define PD_USBFS_ARB_INT_EN_REG     (* (reg8 *) PD_USBFS_USB__ARB_INT_EN)
#define PD_USBFS_ARB_INT_SR_PTR     (  (reg8 *) PD_USBFS_USB__ARB_INT_SR)
#define PD_USBFS_ARB_INT_SR_REG     (* (reg8 *) PD_USBFS_USB__ARB_INT_SR)

#define PD_USBFS_ARB_RW1_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW1_DR)
#define PD_USBFS_ARB_RW1_DR_IND     PD_USBFS_USB__ARB_RW1_DR
#define PD_USBFS_ARB_RW1_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW1_RA)
#define PD_USBFS_ARB_RW1_RA_IND     PD_USBFS_USB__ARB_RW1_RA
#define PD_USBFS_ARB_RW1_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW1_RA_MSB)
#define PD_USBFS_ARB_RW1_RA_MSB_IND PD_USBFS_USB__ARB_RW1_RA_MSB
#define PD_USBFS_ARB_RW1_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW1_WA)
#define PD_USBFS_ARB_RW1_WA_IND     PD_USBFS_USB__ARB_RW1_WA
#define PD_USBFS_ARB_RW1_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW1_WA_MSB)
#define PD_USBFS_ARB_RW1_WA_MSB_IND PD_USBFS_USB__ARB_RW1_WA_MSB

#define PD_USBFS_ARB_RW2_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW2_DR)
#define PD_USBFS_ARB_RW2_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW2_RA)
#define PD_USBFS_ARB_RW2_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW2_RA_MSB)
#define PD_USBFS_ARB_RW2_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW2_WA)
#define PD_USBFS_ARB_RW2_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW2_WA_MSB)

#define PD_USBFS_ARB_RW3_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW3_DR)
#define PD_USBFS_ARB_RW3_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW3_RA)
#define PD_USBFS_ARB_RW3_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW3_RA_MSB)
#define PD_USBFS_ARB_RW3_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW3_WA)
#define PD_USBFS_ARB_RW3_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW3_WA_MSB)

#define PD_USBFS_ARB_RW4_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW4_DR)
#define PD_USBFS_ARB_RW4_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW4_RA)
#define PD_USBFS_ARB_RW4_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW4_RA_MSB)
#define PD_USBFS_ARB_RW4_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW4_WA)
#define PD_USBFS_ARB_RW4_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW4_WA_MSB)

#define PD_USBFS_ARB_RW5_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW5_DR)
#define PD_USBFS_ARB_RW5_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW5_RA)
#define PD_USBFS_ARB_RW5_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW5_RA_MSB)
#define PD_USBFS_ARB_RW5_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW5_WA)
#define PD_USBFS_ARB_RW5_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW5_WA_MSB)

#define PD_USBFS_ARB_RW6_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW6_DR)
#define PD_USBFS_ARB_RW6_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW6_RA)
#define PD_USBFS_ARB_RW6_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW6_RA_MSB)
#define PD_USBFS_ARB_RW6_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW6_WA)
#define PD_USBFS_ARB_RW6_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW6_WA_MSB)

#define PD_USBFS_ARB_RW7_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW7_DR)
#define PD_USBFS_ARB_RW7_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW7_RA)
#define PD_USBFS_ARB_RW7_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW7_RA_MSB)
#define PD_USBFS_ARB_RW7_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW7_WA)
#define PD_USBFS_ARB_RW7_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW7_WA_MSB)

#define PD_USBFS_ARB_RW8_DR_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW8_DR)
#define PD_USBFS_ARB_RW8_RA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW8_RA)
#define PD_USBFS_ARB_RW8_RA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW8_RA_MSB)
#define PD_USBFS_ARB_RW8_WA_PTR     ((reg8 *) PD_USBFS_USB__ARB_RW8_WA)
#define PD_USBFS_ARB_RW8_WA_MSB_PTR ((reg8 *) PD_USBFS_USB__ARB_RW8_WA_MSB)

#define PD_USBFS_BUF_SIZE_PTR       (  (reg8 *) PD_USBFS_USB__BUF_SIZE)
#define PD_USBFS_BUF_SIZE_REG       (* (reg8 *) PD_USBFS_USB__BUF_SIZE)
#define PD_USBFS_BUS_RST_CNT_PTR    (  (reg8 *) PD_USBFS_USB__BUS_RST_CNT)
#define PD_USBFS_BUS_RST_CNT_REG    (* (reg8 *) PD_USBFS_USB__BUS_RST_CNT)
#define PD_USBFS_CWA_PTR            (  (reg8 *) PD_USBFS_USB__CWA)
#define PD_USBFS_CWA_REG            (* (reg8 *) PD_USBFS_USB__CWA)
#define PD_USBFS_CWA_MSB_PTR        (  (reg8 *) PD_USBFS_USB__CWA_MSB)
#define PD_USBFS_CWA_MSB_REG        (* (reg8 *) PD_USBFS_USB__CWA_MSB)
#define PD_USBFS_CR0_PTR            (  (reg8 *) PD_USBFS_USB__CR0)
#define PD_USBFS_CR0_REG            (* (reg8 *) PD_USBFS_USB__CR0)
#define PD_USBFS_CR1_PTR            (  (reg8 *) PD_USBFS_USB__CR1)
#define PD_USBFS_CR1_REG            (* (reg8 *) PD_USBFS_USB__CR1)

#define PD_USBFS_DMA_THRES_PTR      (  (reg8 *) PD_USBFS_USB__DMA_THRES)
#define PD_USBFS_DMA_THRES_REG      (* (reg8 *) PD_USBFS_USB__DMA_THRES)
#define PD_USBFS_DMA_THRES_MSB_PTR  (  (reg8 *) PD_USBFS_USB__DMA_THRES_MSB)
#define PD_USBFS_DMA_THRES_MSB_REG  (* (reg8 *) PD_USBFS_USB__DMA_THRES_MSB)

#define PD_USBFS_EP_ACTIVE_PTR      (  (reg8 *) PD_USBFS_USB__EP_ACTIVE)
#define PD_USBFS_EP_ACTIVE_REG      (* (reg8 *) PD_USBFS_USB__EP_ACTIVE)
#define PD_USBFS_EP_TYPE_PTR        (  (reg8 *) PD_USBFS_USB__EP_TYPE)
#define PD_USBFS_EP_TYPE_REG        (* (reg8 *) PD_USBFS_USB__EP_TYPE)

#define PD_USBFS_EP0_CNT_PTR        (  (reg8 *) PD_USBFS_USB__EP0_CNT)
#define PD_USBFS_EP0_CNT_REG        (* (reg8 *) PD_USBFS_USB__EP0_CNT)
#define PD_USBFS_EP0_CR_PTR         (  (reg8 *) PD_USBFS_USB__EP0_CR)
#define PD_USBFS_EP0_CR_REG         (* (reg8 *) PD_USBFS_USB__EP0_CR)
#define PD_USBFS_EP0_DR0_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR0)
#define PD_USBFS_EP0_DR0_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR0)
#define PD_USBFS_EP0_DR0_IND        PD_USBFS_USB__EP0_DR0
#define PD_USBFS_EP0_DR1_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR1)
#define PD_USBFS_EP0_DR1_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR1)
#define PD_USBFS_EP0_DR2_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR2)
#define PD_USBFS_EP0_DR2_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR2)
#define PD_USBFS_EP0_DR3_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR3)
#define PD_USBFS_EP0_DR3_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR3)
#define PD_USBFS_EP0_DR4_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR4)
#define PD_USBFS_EP0_DR4_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR4)
#define PD_USBFS_EP0_DR5_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR5)
#define PD_USBFS_EP0_DR5_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR5)
#define PD_USBFS_EP0_DR6_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR6)
#define PD_USBFS_EP0_DR6_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR6)
#define PD_USBFS_EP0_DR7_PTR        (  (reg8 *) PD_USBFS_USB__EP0_DR7)
#define PD_USBFS_EP0_DR7_REG        (* (reg8 *) PD_USBFS_USB__EP0_DR7)

#define PD_USBFS_OSCLK_DR0_PTR      (  (reg8 *) PD_USBFS_USB__OSCLK_DR0)
#define PD_USBFS_OSCLK_DR0_REG      (* (reg8 *) PD_USBFS_USB__OSCLK_DR0)
#define PD_USBFS_OSCLK_DR1_PTR      (  (reg8 *) PD_USBFS_USB__OSCLK_DR1)
#define PD_USBFS_OSCLK_DR1_REG      (* (reg8 *) PD_USBFS_USB__OSCLK_DR1)

#define PD_USBFS_PM_ACT_CFG_PTR     (  (reg8 *) PD_USBFS_USB__PM_ACT_CFG)
#define PD_USBFS_PM_ACT_CFG_REG     (* (reg8 *) PD_USBFS_USB__PM_ACT_CFG)
#define PD_USBFS_PM_STBY_CFG_PTR    (  (reg8 *) PD_USBFS_USB__PM_STBY_CFG)
#define PD_USBFS_PM_STBY_CFG_REG    (* (reg8 *) PD_USBFS_USB__PM_STBY_CFG)

#define PD_USBFS_SIE_EP_INT_EN_PTR  (  (reg8 *) PD_USBFS_USB__SIE_EP_INT_EN)
#define PD_USBFS_SIE_EP_INT_EN_REG  (* (reg8 *) PD_USBFS_USB__SIE_EP_INT_EN)
#define PD_USBFS_SIE_EP_INT_SR_PTR  (  (reg8 *) PD_USBFS_USB__SIE_EP_INT_SR)
#define PD_USBFS_SIE_EP_INT_SR_REG  (* (reg8 *) PD_USBFS_USB__SIE_EP_INT_SR)

#define PD_USBFS_SIE_EP1_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP1_CNT0)
#define PD_USBFS_SIE_EP1_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP1_CNT0)
#define PD_USBFS_SIE_EP1_CNT0_IND   PD_USBFS_USB__SIE_EP1_CNT0
#define PD_USBFS_SIE_EP1_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP1_CNT1)
#define PD_USBFS_SIE_EP1_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP1_CNT1)
#define PD_USBFS_SIE_EP1_CNT1_IND   PD_USBFS_USB__SIE_EP1_CNT1
#define PD_USBFS_SIE_EP1_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP1_CR0)
#define PD_USBFS_SIE_EP1_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP1_CR0)
#define PD_USBFS_SIE_EP1_CR0_IND    PD_USBFS_USB__SIE_EP1_CR0

#define PD_USBFS_SIE_EP2_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP2_CNT0)
#define PD_USBFS_SIE_EP2_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP2_CNT0)
#define PD_USBFS_SIE_EP2_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP2_CNT1)
#define PD_USBFS_SIE_EP2_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP2_CNT1)
#define PD_USBFS_SIE_EP2_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP2_CR0)
#define PD_USBFS_SIE_EP2_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP2_CR0)

#define PD_USBFS_SIE_EP3_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP3_CNT0)
#define PD_USBFS_SIE_EP3_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP3_CNT0)
#define PD_USBFS_SIE_EP3_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP3_CNT1)
#define PD_USBFS_SIE_EP3_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP3_CNT1)
#define PD_USBFS_SIE_EP3_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP3_CR0)
#define PD_USBFS_SIE_EP3_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP3_CR0)

#define PD_USBFS_SIE_EP4_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP4_CNT0)
#define PD_USBFS_SIE_EP4_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP4_CNT0)
#define PD_USBFS_SIE_EP4_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP4_CNT1)
#define PD_USBFS_SIE_EP4_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP4_CNT1)
#define PD_USBFS_SIE_EP4_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP4_CR0)
#define PD_USBFS_SIE_EP4_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP4_CR0)

#define PD_USBFS_SIE_EP5_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP5_CNT0)
#define PD_USBFS_SIE_EP5_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP5_CNT0)
#define PD_USBFS_SIE_EP5_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP5_CNT1)
#define PD_USBFS_SIE_EP5_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP5_CNT1)
#define PD_USBFS_SIE_EP5_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP5_CR0)
#define PD_USBFS_SIE_EP5_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP5_CR0)

#define PD_USBFS_SIE_EP6_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP6_CNT0)
#define PD_USBFS_SIE_EP6_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP6_CNT0)
#define PD_USBFS_SIE_EP6_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP6_CNT1)
#define PD_USBFS_SIE_EP6_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP6_CNT1)
#define PD_USBFS_SIE_EP6_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP6_CR0)
#define PD_USBFS_SIE_EP6_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP6_CR0)

#define PD_USBFS_SIE_EP7_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP7_CNT0)
#define PD_USBFS_SIE_EP7_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP7_CNT0)
#define PD_USBFS_SIE_EP7_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP7_CNT1)
#define PD_USBFS_SIE_EP7_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP7_CNT1)
#define PD_USBFS_SIE_EP7_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP7_CR0)
#define PD_USBFS_SIE_EP7_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP7_CR0)

#define PD_USBFS_SIE_EP8_CNT0_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP8_CNT0)
#define PD_USBFS_SIE_EP8_CNT0_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP8_CNT0)
#define PD_USBFS_SIE_EP8_CNT1_PTR   (  (reg8 *) PD_USBFS_USB__SIE_EP8_CNT1)
#define PD_USBFS_SIE_EP8_CNT1_REG   (* (reg8 *) PD_USBFS_USB__SIE_EP8_CNT1)
#define PD_USBFS_SIE_EP8_CR0_PTR    (  (reg8 *) PD_USBFS_USB__SIE_EP8_CR0)
#define PD_USBFS_SIE_EP8_CR0_REG    (* (reg8 *) PD_USBFS_USB__SIE_EP8_CR0)

#define PD_USBFS_SOF0_PTR           (  (reg8 *) PD_USBFS_USB__SOF0)
#define PD_USBFS_SOF0_REG           (* (reg8 *) PD_USBFS_USB__SOF0)
#define PD_USBFS_SOF1_PTR           (  (reg8 *) PD_USBFS_USB__SOF1)
#define PD_USBFS_SOF1_REG           (* (reg8 *) PD_USBFS_USB__SOF1)

#define PD_USBFS_USB_CLK_EN_PTR     (  (reg8 *) PD_USBFS_USB__USB_CLK_EN)
#define PD_USBFS_USB_CLK_EN_REG     (* (reg8 *) PD_USBFS_USB__USB_CLK_EN)

#define PD_USBFS_USBIO_CR0_PTR      (  (reg8 *) PD_USBFS_USB__USBIO_CR0)
#define PD_USBFS_USBIO_CR0_REG      (* (reg8 *) PD_USBFS_USB__USBIO_CR0)
#define PD_USBFS_USBIO_CR1_PTR      (  (reg8 *) PD_USBFS_USB__USBIO_CR1)
#define PD_USBFS_USBIO_CR1_REG      (* (reg8 *) PD_USBFS_USB__USBIO_CR1)
#if(!CY_PSOC5LP)
    #define PD_USBFS_USBIO_CR2_PTR      (  (reg8 *) PD_USBFS_USB__USBIO_CR2)
    #define PD_USBFS_USBIO_CR2_REG      (* (reg8 *) PD_USBFS_USB__USBIO_CR2)
#endif /*  CY_PSOC5LP */

#define PD_USBFS_DIE_ID             CYDEV_FLSHID_CUST_TABLES_BASE

#define PD_USBFS_PM_USB_CR0_PTR     (  (reg8 *) CYREG_PM_USB_CR0)
#define PD_USBFS_PM_USB_CR0_REG     (* (reg8 *) CYREG_PM_USB_CR0)
#define PD_USBFS_DYN_RECONFIG_PTR   (  (reg8 *) PD_USBFS_USB__DYN_RECONFIG)
#define PD_USBFS_DYN_RECONFIG_REG   (* (reg8 *) PD_USBFS_USB__DYN_RECONFIG)

#define PD_USBFS_DM_INP_DIS_PTR     (  (reg8 *) PD_USBFS_Dm__INP_DIS)
#define PD_USBFS_DM_INP_DIS_REG     (* (reg8 *) PD_USBFS_Dm__INP_DIS)
#define PD_USBFS_DP_INP_DIS_PTR     (  (reg8 *) PD_USBFS_Dp__INP_DIS)
#define PD_USBFS_DP_INP_DIS_REG     (* (reg8 *) PD_USBFS_Dp__INP_DIS)
#define PD_USBFS_DP_INTSTAT_PTR     (  (reg8 *) PD_USBFS_Dp__INTSTAT)
#define PD_USBFS_DP_INTSTAT_REG     (* (reg8 *) PD_USBFS_Dp__INTSTAT)

#if (PD_USBFS_MON_VBUS == 1u)
    #if (PD_USBFS_EXTERN_VBUS == 0u)
        #define PD_USBFS_VBUS_DR_PTR        (  (reg8 *) PD_USBFS_VBUS__DR)
        #define PD_USBFS_VBUS_DR_REG        (* (reg8 *) PD_USBFS_VBUS__DR)
        #define PD_USBFS_VBUS_PS_PTR        (  (reg8 *) PD_USBFS_VBUS__PS)
        #define PD_USBFS_VBUS_PS_REG        (* (reg8 *) PD_USBFS_VBUS__PS)
        #define PD_USBFS_VBUS_MASK          PD_USBFS_VBUS__MASK
    #else
        #define PD_USBFS_VBUS_PS_PTR        (  (reg8 *) PD_USBFS_Vbus_ps_sts_sts_reg__STATUS_REG )
        #define PD_USBFS_VBUS_MASK          (0x01u)
    #endif /*  PD_USBFS_EXTERN_VBUS == 0u */
#endif /*  PD_USBFS_MON_VBUS */

/* Renamed Registers for backward compatibility.
*  Should not be used in new designs.
*/
#define PD_USBFS_ARB_CFG        PD_USBFS_ARB_CFG_PTR

#define PD_USBFS_ARB_EP1_CFG    PD_USBFS_ARB_EP1_CFG_PTR
#define PD_USBFS_ARB_EP1_INT_EN PD_USBFS_ARB_EP1_INT_EN_PTR
#define PD_USBFS_ARB_EP1_SR     PD_USBFS_ARB_EP1_SR_PTR

#define PD_USBFS_ARB_EP2_CFG    PD_USBFS_ARB_EP2_CFG_PTR
#define PD_USBFS_ARB_EP2_INT_EN PD_USBFS_ARB_EP2_INT_EN_PTR
#define PD_USBFS_ARB_EP2_SR     PD_USBFS_ARB_EP2_SR_PTR

#define PD_USBFS_ARB_EP3_CFG    PD_USBFS_ARB_EP3_CFG_PTR
#define PD_USBFS_ARB_EP3_INT_EN PD_USBFS_ARB_EP3_INT_EN_PTR
#define PD_USBFS_ARB_EP3_SR     PD_USBFS_ARB_EP3_SR_PTR

#define PD_USBFS_ARB_EP4_CFG    PD_USBFS_ARB_EP4_CFG_PTR
#define PD_USBFS_ARB_EP4_INT_EN PD_USBFS_ARB_EP4_INT_EN_PTR
#define PD_USBFS_ARB_EP4_SR     PD_USBFS_ARB_EP4_SR_PTR

#define PD_USBFS_ARB_EP5_CFG    PD_USBFS_ARB_EP5_CFG_PTR
#define PD_USBFS_ARB_EP5_INT_EN PD_USBFS_ARB_EP5_INT_EN_PTR
#define PD_USBFS_ARB_EP5_SR     PD_USBFS_ARB_EP5_SR_PTR

#define PD_USBFS_ARB_EP6_CFG    PD_USBFS_ARB_EP6_CFG_PTR
#define PD_USBFS_ARB_EP6_INT_EN PD_USBFS_ARB_EP6_INT_EN_PTR
#define PD_USBFS_ARB_EP6_SR     PD_USBFS_ARB_EP6_SR_PTR

#define PD_USBFS_ARB_EP7_CFG    PD_USBFS_ARB_EP7_CFG_PTR
#define PD_USBFS_ARB_EP7_INT_EN PD_USBFS_ARB_EP7_INT_EN_PTR
#define PD_USBFS_ARB_EP7_SR     PD_USBFS_ARB_EP7_SR_PTR

#define PD_USBFS_ARB_EP8_CFG    PD_USBFS_ARB_EP8_CFG_PTR
#define PD_USBFS_ARB_EP8_INT_EN PD_USBFS_ARB_EP8_INT_EN_PTR
#define PD_USBFS_ARB_EP8_SR     PD_USBFS_ARB_EP8_SR_PTR

#define PD_USBFS_ARB_INT_EN     PD_USBFS_ARB_INT_EN_PTR
#define PD_USBFS_ARB_INT_SR     PD_USBFS_ARB_INT_SR_PTR

#define PD_USBFS_ARB_RW1_DR     PD_USBFS_ARB_RW1_DR_PTR
#define PD_USBFS_ARB_RW1_RA     PD_USBFS_ARB_RW1_RA_PTR
#define PD_USBFS_ARB_RW1_RA_MSB PD_USBFS_ARB_RW1_RA_MSB_PTR
#define PD_USBFS_ARB_RW1_WA     PD_USBFS_ARB_RW1_WA_PTR
#define PD_USBFS_ARB_RW1_WA_MSB PD_USBFS_ARB_RW1_WA_MSB_PTR

#define PD_USBFS_ARB_RW2_DR     PD_USBFS_ARB_RW2_DR_PTR
#define PD_USBFS_ARB_RW2_RA     PD_USBFS_ARB_RW2_RA_PTR
#define PD_USBFS_ARB_RW2_RA_MSB PD_USBFS_ARB_RW2_RA_MSB_PTR
#define PD_USBFS_ARB_RW2_WA     PD_USBFS_ARB_RW2_WA_PTR
#define PD_USBFS_ARB_RW2_WA_MSB PD_USBFS_ARB_RW2_WA_MSB_PTR

#define PD_USBFS_ARB_RW3_DR     PD_USBFS_ARB_RW3_DR_PTR
#define PD_USBFS_ARB_RW3_RA     PD_USBFS_ARB_RW3_RA_PTR
#define PD_USBFS_ARB_RW3_RA_MSB PD_USBFS_ARB_RW3_RA_MSB_PTR
#define PD_USBFS_ARB_RW3_WA     PD_USBFS_ARB_RW3_WA_PTR
#define PD_USBFS_ARB_RW3_WA_MSB PD_USBFS_ARB_RW3_WA_MSB_PTR

#define PD_USBFS_ARB_RW4_DR     PD_USBFS_ARB_RW4_DR_PTR
#define PD_USBFS_ARB_RW4_RA     PD_USBFS_ARB_RW4_RA_PTR
#define PD_USBFS_ARB_RW4_RA_MSB PD_USBFS_ARB_RW4_RA_MSB_PTR
#define PD_USBFS_ARB_RW4_WA     PD_USBFS_ARB_RW4_WA_PTR
#define PD_USBFS_ARB_RW4_WA_MSB PD_USBFS_ARB_RW4_WA_MSB_PTR

#define PD_USBFS_ARB_RW5_DR     PD_USBFS_ARB_RW5_DR_PTR
#define PD_USBFS_ARB_RW5_RA     PD_USBFS_ARB_RW5_RA_PTR
#define PD_USBFS_ARB_RW5_RA_MSB PD_USBFS_ARB_RW5_RA_MSB_PTR
#define PD_USBFS_ARB_RW5_WA     PD_USBFS_ARB_RW5_WA_PTR
#define PD_USBFS_ARB_RW5_WA_MSB PD_USBFS_ARB_RW5_WA_MSB_PTR

#define PD_USBFS_ARB_RW6_DR     PD_USBFS_ARB_RW6_DR_PTR
#define PD_USBFS_ARB_RW6_RA     PD_USBFS_ARB_RW6_RA_PTR
#define PD_USBFS_ARB_RW6_RA_MSB PD_USBFS_ARB_RW6_RA_MSB_PTR
#define PD_USBFS_ARB_RW6_WA     PD_USBFS_ARB_RW6_WA_PTR
#define PD_USBFS_ARB_RW6_WA_MSB PD_USBFS_ARB_RW6_WA_MSB_PTR

#define PD_USBFS_ARB_RW7_DR     PD_USBFS_ARB_RW7_DR_PTR
#define PD_USBFS_ARB_RW7_RA     PD_USBFS_ARB_RW7_RA_PTR
#define PD_USBFS_ARB_RW7_RA_MSB PD_USBFS_ARB_RW7_RA_MSB_PTR
#define PD_USBFS_ARB_RW7_WA     PD_USBFS_ARB_RW7_WA_PTR
#define PD_USBFS_ARB_RW7_WA_MSB PD_USBFS_ARB_RW7_WA_MSB_PTR

#define PD_USBFS_ARB_RW8_DR     PD_USBFS_ARB_RW8_DR_PTR
#define PD_USBFS_ARB_RW8_RA     PD_USBFS_ARB_RW8_RA_PTR
#define PD_USBFS_ARB_RW8_RA_MSB PD_USBFS_ARB_RW8_RA_MSB_PTR
#define PD_USBFS_ARB_RW8_WA     PD_USBFS_ARB_RW8_WA_PTR
#define PD_USBFS_ARB_RW8_WA_MSB PD_USBFS_ARB_RW8_WA_MSB_PTR

#define PD_USBFS_BUF_SIZE       PD_USBFS_BUF_SIZE_PTR
#define PD_USBFS_BUS_RST_CNT    PD_USBFS_BUS_RST_CNT_PTR
#define PD_USBFS_CR0            PD_USBFS_CR0_PTR
#define PD_USBFS_CR1            PD_USBFS_CR1_PTR
#define PD_USBFS_CWA            PD_USBFS_CWA_PTR
#define PD_USBFS_CWA_MSB        PD_USBFS_CWA_MSB_PTR

#define PD_USBFS_DMA_THRES      PD_USBFS_DMA_THRES_PTR
#define PD_USBFS_DMA_THRES_MSB  PD_USBFS_DMA_THRES_MSB_PTR

#define PD_USBFS_EP_ACTIVE      PD_USBFS_EP_ACTIVE_PTR
#define PD_USBFS_EP_TYPE        PD_USBFS_EP_TYPE_PTR

#define PD_USBFS_EP0_CNT        PD_USBFS_EP0_CNT_PTR
#define PD_USBFS_EP0_CR         PD_USBFS_EP0_CR_PTR
#define PD_USBFS_EP0_DR0        PD_USBFS_EP0_DR0_PTR
#define PD_USBFS_EP0_DR1        PD_USBFS_EP0_DR1_PTR
#define PD_USBFS_EP0_DR2        PD_USBFS_EP0_DR2_PTR
#define PD_USBFS_EP0_DR3        PD_USBFS_EP0_DR3_PTR
#define PD_USBFS_EP0_DR4        PD_USBFS_EP0_DR4_PTR
#define PD_USBFS_EP0_DR5        PD_USBFS_EP0_DR5_PTR
#define PD_USBFS_EP0_DR6        PD_USBFS_EP0_DR6_PTR
#define PD_USBFS_EP0_DR7        PD_USBFS_EP0_DR7_PTR

#define PD_USBFS_OSCLK_DR0      PD_USBFS_OSCLK_DR0_PTR
#define PD_USBFS_OSCLK_DR1      PD_USBFS_OSCLK_DR1_PTR

#define PD_USBFS_PM_ACT_CFG     PD_USBFS_PM_ACT_CFG_PTR
#define PD_USBFS_PM_STBY_CFG    PD_USBFS_PM_STBY_CFG_PTR

#define PD_USBFS_SIE_EP_INT_EN  PD_USBFS_SIE_EP_INT_EN_PTR
#define PD_USBFS_SIE_EP_INT_SR  PD_USBFS_SIE_EP_INT_SR_PTR

#define PD_USBFS_SIE_EP1_CNT0   PD_USBFS_SIE_EP1_CNT0_PTR
#define PD_USBFS_SIE_EP1_CNT1   PD_USBFS_SIE_EP1_CNT1_PTR
#define PD_USBFS_SIE_EP1_CR0    PD_USBFS_SIE_EP1_CR0_PTR

#define PD_USBFS_SIE_EP2_CNT0   PD_USBFS_SIE_EP2_CNT0_PTR
#define PD_USBFS_SIE_EP2_CNT1   PD_USBFS_SIE_EP2_CNT1_PTR
#define PD_USBFS_SIE_EP2_CR0    PD_USBFS_SIE_EP2_CR0_PTR

#define PD_USBFS_SIE_EP3_CNT0   PD_USBFS_SIE_EP3_CNT0_PTR
#define PD_USBFS_SIE_EP3_CNT1   PD_USBFS_SIE_EP3_CNT1_PTR
#define PD_USBFS_SIE_EP3_CR0    PD_USBFS_SIE_EP3_CR0_PTR

#define PD_USBFS_SIE_EP4_CNT0   PD_USBFS_SIE_EP4_CNT0_PTR
#define PD_USBFS_SIE_EP4_CNT1   PD_USBFS_SIE_EP4_CNT1_PTR
#define PD_USBFS_SIE_EP4_CR0    PD_USBFS_SIE_EP4_CR0_PTR

#define PD_USBFS_SIE_EP5_CNT0   PD_USBFS_SIE_EP5_CNT0_PTR
#define PD_USBFS_SIE_EP5_CNT1   PD_USBFS_SIE_EP5_CNT1_PTR
#define PD_USBFS_SIE_EP5_CR0    PD_USBFS_SIE_EP5_CR0_PTR

#define PD_USBFS_SIE_EP6_CNT0   PD_USBFS_SIE_EP6_CNT0_PTR
#define PD_USBFS_SIE_EP6_CNT1   PD_USBFS_SIE_EP6_CNT1_PTR
#define PD_USBFS_SIE_EP6_CR0    PD_USBFS_SIE_EP6_CR0_PTR

#define PD_USBFS_SIE_EP7_CNT0   PD_USBFS_SIE_EP7_CNT0_PTR
#define PD_USBFS_SIE_EP7_CNT1   PD_USBFS_SIE_EP7_CNT1_PTR
#define PD_USBFS_SIE_EP7_CR0    PD_USBFS_SIE_EP7_CR0_PTR

#define PD_USBFS_SIE_EP8_CNT0   PD_USBFS_SIE_EP8_CNT0_PTR
#define PD_USBFS_SIE_EP8_CNT1   PD_USBFS_SIE_EP8_CNT1_PTR
#define PD_USBFS_SIE_EP8_CR0    PD_USBFS_SIE_EP8_CR0_PTR

#define PD_USBFS_SOF0           PD_USBFS_SOF0_PTR
#define PD_USBFS_SOF1           PD_USBFS_SOF1_PTR

#define PD_USBFS_USB_CLK_EN     PD_USBFS_USB_CLK_EN_PTR

#define PD_USBFS_USBIO_CR0      PD_USBFS_USBIO_CR0_PTR
#define PD_USBFS_USBIO_CR1      PD_USBFS_USBIO_CR1_PTR
#define PD_USBFS_USBIO_CR2      PD_USBFS_USBIO_CR2_PTR

#define PD_USBFS_USB_MEM        ((reg8 *) CYDEV_USB_MEM_BASE)

#if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
    /* PSoC3 interrupt registers*/
    #define PD_USBFS_USB_ISR_PRIOR  ((reg8 *) CYDEV_INTC_PRIOR0)
    #define PD_USBFS_USB_ISR_SET_EN ((reg8 *) CYDEV_INTC_SET_EN0)
    #define PD_USBFS_USB_ISR_CLR_EN ((reg8 *) CYDEV_INTC_CLR_EN0)
    #define PD_USBFS_USB_ISR_VECT   ((cyisraddress *) CYDEV_INTC_VECT_MBASE)
#elif(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_PANTHER)
    /* PSoC5 interrupt registers*/
    #define PD_USBFS_USB_ISR_PRIOR  ((reg8 *) CYDEV_NVIC_PRI_0)
    #define PD_USBFS_USB_ISR_SET_EN ((reg8 *) CYDEV_NVIC_SETENA0)
    #define PD_USBFS_USB_ISR_CLR_EN ((reg8 *) CYDEV_NVIC_CLRENA0)
    #define PD_USBFS_USB_ISR_VECT   ((cyisraddress *) CYDEV_NVIC_VECT_OFFSET)
#endif /*  CYDEV_CHIP_DIE_EXPECT */


/***************************************
* Interrupt vectors, masks and priorities
***************************************/

#define PD_USBFS_BUS_RESET_PRIOR    PD_USBFS_bus_reset__INTC_PRIOR_NUM
#define PD_USBFS_BUS_RESET_MASK     PD_USBFS_bus_reset__INTC_MASK
#define PD_USBFS_BUS_RESET_VECT_NUM PD_USBFS_bus_reset__INTC_NUMBER

#define PD_USBFS_SOF_PRIOR          PD_USBFS_sof_int__INTC_PRIOR_NUM
#define PD_USBFS_SOF_MASK           PD_USBFS_sof_int__INTC_MASK
#define PD_USBFS_SOF_VECT_NUM       PD_USBFS_sof_int__INTC_NUMBER

#define PD_USBFS_EP_0_PRIOR         PD_USBFS_ep_0__INTC_PRIOR_NUM
#define PD_USBFS_EP_0_MASK          PD_USBFS_ep_0__INTC_MASK
#define PD_USBFS_EP_0_VECT_NUM      PD_USBFS_ep_0__INTC_NUMBER

#define PD_USBFS_EP_1_PRIOR         PD_USBFS_ep_1__INTC_PRIOR_NUM
#define PD_USBFS_EP_1_MASK          PD_USBFS_ep_1__INTC_MASK
#define PD_USBFS_EP_1_VECT_NUM      PD_USBFS_ep_1__INTC_NUMBER

#define PD_USBFS_EP_2_PRIOR         PD_USBFS_ep_2__INTC_PRIOR_NUM
#define PD_USBFS_EP_2_MASK          PD_USBFS_ep_2__INTC_MASK
#define PD_USBFS_EP_2_VECT_NUM      PD_USBFS_ep_2__INTC_NUMBER

#define PD_USBFS_EP_3_PRIOR         PD_USBFS_ep_3__INTC_PRIOR_NUM
#define PD_USBFS_EP_3_MASK          PD_USBFS_ep_3__INTC_MASK
#define PD_USBFS_EP_3_VECT_NUM      PD_USBFS_ep_3__INTC_NUMBER

#define PD_USBFS_EP_4_PRIOR         PD_USBFS_ep_4__INTC_PRIOR_NUM
#define PD_USBFS_EP_4_MASK          PD_USBFS_ep_4__INTC_MASK
#define PD_USBFS_EP_4_VECT_NUM      PD_USBFS_ep_4__INTC_NUMBER

#define PD_USBFS_EP_5_PRIOR         PD_USBFS_ep_5__INTC_PRIOR_NUM
#define PD_USBFS_EP_5_MASK          PD_USBFS_ep_5__INTC_MASK
#define PD_USBFS_EP_5_VECT_NUM      PD_USBFS_ep_5__INTC_NUMBER

#define PD_USBFS_EP_6_PRIOR         PD_USBFS_ep_6__INTC_PRIOR_NUM
#define PD_USBFS_EP_6_MASK          PD_USBFS_ep_6__INTC_MASK
#define PD_USBFS_EP_6_VECT_NUM      PD_USBFS_ep_6__INTC_NUMBER

#define PD_USBFS_EP_7_PRIOR         PD_USBFS_ep_7__INTC_PRIOR_NUM
#define PD_USBFS_EP_7_MASK          PD_USBFS_ep_7__INTC_MASK
#define PD_USBFS_EP_7_VECT_NUM      PD_USBFS_ep_7__INTC_NUMBER

#define PD_USBFS_EP_8_PRIOR         PD_USBFS_ep_8__INTC_PRIOR_NUM
#define PD_USBFS_EP_8_MASK          PD_USBFS_ep_8__INTC_MASK
#define PD_USBFS_EP_8_VECT_NUM      PD_USBFS_ep_8__INTC_NUMBER

#define PD_USBFS_DP_INTC_PRIOR      PD_USBFS_dp_int__INTC_PRIOR_NUM
#define PD_USBFS_DP_INTC_MASK       PD_USBFS_dp_int__INTC_MASK
#define PD_USBFS_DP_INTC_VECT_NUM   PD_USBFS_dp_int__INTC_NUMBER

/* ARB ISR should have higher priority from EP_X ISR, therefore it is defined to highest (0) */
#define PD_USBFS_ARB_PRIOR          (0u)
#define PD_USBFS_ARB_MASK           PD_USBFS_arb_int__INTC_MASK
#define PD_USBFS_ARB_VECT_NUM       PD_USBFS_arb_int__INTC_NUMBER

/***************************************
 *  Endpoint 0 offsets (Table 9-2)
 **************************************/

#define PD_USBFS_bmRequestType      PD_USBFS_EP0_DR0_PTR
#define PD_USBFS_bRequest           PD_USBFS_EP0_DR1_PTR
#define PD_USBFS_wValue             PD_USBFS_EP0_DR2_PTR
#define PD_USBFS_wValueHi           PD_USBFS_EP0_DR3_PTR
#define PD_USBFS_wValueLo           PD_USBFS_EP0_DR2_PTR
#define PD_USBFS_wIndex             PD_USBFS_EP0_DR4_PTR
#define PD_USBFS_wIndexHi           PD_USBFS_EP0_DR5_PTR
#define PD_USBFS_wIndexLo           PD_USBFS_EP0_DR4_PTR
#define PD_USBFS_length             PD_USBFS_EP0_DR6_PTR
#define PD_USBFS_lengthHi           PD_USBFS_EP0_DR7_PTR
#define PD_USBFS_lengthLo           PD_USBFS_EP0_DR6_PTR


/***************************************
*       Register Constants
***************************************/
#define PD_USBFS_VDDD_MV                    CYDEV_VDDD_MV
#define PD_USBFS_3500MV                     (3500u)

#define PD_USBFS_CR1_REG_ENABLE             (0x01u)
#define PD_USBFS_CR1_ENABLE_LOCK            (0x02u)
#define PD_USBFS_CR1_BUS_ACTIVITY_SHIFT     (0x02u)
#define PD_USBFS_CR1_BUS_ACTIVITY           ((uint8)(0x01u << PD_USBFS_CR1_BUS_ACTIVITY_SHIFT))
#define PD_USBFS_CR1_TRIM_MSB_EN            (0x08u)

#define PD_USBFS_EP0_CNT_DATA_TOGGLE        (0x80u)
#define PD_USBFS_EPX_CNT_DATA_TOGGLE        (0x80u)
#define PD_USBFS_EPX_CNT0_MASK              (0x0Fu)
#define PD_USBFS_EPX_CNTX_MSB_MASK          (0x07u)
#define PD_USBFS_EPX_CNTX_ADDR_SHIFT        (0x04u)
#define PD_USBFS_EPX_CNTX_ADDR_OFFSET       (0x10u)
#define PD_USBFS_EPX_CNTX_CRC_COUNT         (0x02u)
#define PD_USBFS_EPX_DATA_BUF_MAX           (512u)

#define PD_USBFS_CR0_ENABLE                 (0x80u)

/* A 100 KHz clock is used for BUS reset count. Recommended is to count 10 pulses */
#define PD_USBFS_BUS_RST_COUNT              (0x0au)

#define PD_USBFS_USBIO_CR1_IOMODE           (0x20u)
#define PD_USBFS_USBIO_CR1_USBPUEN          (0x04u)
#define PD_USBFS_USBIO_CR1_DP0              (0x02u)
#define PD_USBFS_USBIO_CR1_DM0              (0x01u)

#define PD_USBFS_USBIO_CR0_TEN              (0x80u)
#define PD_USBFS_USBIO_CR0_TSE0             (0x40u)
#define PD_USBFS_USBIO_CR0_TD               (0x20u)
#define PD_USBFS_USBIO_CR0_RD               (0x01u)

#define PD_USBFS_FASTCLK_IMO_CR_USBCLK_ON   (0x40u)
#define PD_USBFS_FASTCLK_IMO_CR_XCLKEN      (0x20u)
#define PD_USBFS_FASTCLK_IMO_CR_FX2ON       (0x10u)

#define PD_USBFS_ARB_EPX_CFG_RESET          (0x08u)
#define PD_USBFS_ARB_EPX_CFG_CRC_BYPASS     (0x04u)
#define PD_USBFS_ARB_EPX_CFG_DMA_REQ        (0x02u)
#define PD_USBFS_ARB_EPX_CFG_IN_DATA_RDY    (0x01u)
#define PD_USBFS_ARB_EPX_CFG_DEFAULT        (PD_USBFS_ARB_EPX_CFG_RESET | \
                                                     PD_USBFS_ARB_EPX_CFG_CRC_BYPASS)

#define PD_USBFS_ARB_EPX_SR_IN_BUF_FULL     (0x01u)
#define PD_USBFS_ARB_EPX_SR_DMA_GNT         (0x02u)
#define PD_USBFS_ARB_EPX_SR_BUF_OVER        (0x04u)
#define PD_USBFS_ARB_EPX_SR_BUF_UNDER       (0x08u)

#define PD_USBFS_ARB_CFG_AUTO_MEM           (0x10u)
#define PD_USBFS_ARB_CFG_MANUAL_DMA         (0x20u)
#define PD_USBFS_ARB_CFG_AUTO_DMA           (0x40u)
#define PD_USBFS_ARB_CFG_CFG_CPM            (0x80u)

#if(PD_USBFS_EP_MM == PD_USBFS__EP_DMAAUTO)
    #define PD_USBFS_ARB_EPX_INT_MASK           (0x1Du)
#else
    #define PD_USBFS_ARB_EPX_INT_MASK           (0x1Fu)
#endif /*  PD_USBFS_EP_MM == PD_USBFS__EP_DMAAUTO */
#define PD_USBFS_ARB_INT_MASK       (uint8)((PD_USBFS_DMA1_REMOVE ^ 1u) | \
                                            (uint8)((PD_USBFS_DMA2_REMOVE ^ 1u) << 1u) | \
                                            (uint8)((PD_USBFS_DMA3_REMOVE ^ 1u) << 2u) | \
                                            (uint8)((PD_USBFS_DMA4_REMOVE ^ 1u) << 3u) | \
                                            (uint8)((PD_USBFS_DMA5_REMOVE ^ 1u) << 4u) | \
                                            (uint8)((PD_USBFS_DMA6_REMOVE ^ 1u) << 5u) | \
                                            (uint8)((PD_USBFS_DMA7_REMOVE ^ 1u) << 6u) | \
                                            (uint8)((PD_USBFS_DMA8_REMOVE ^ 1u) << 7u) )

#define PD_USBFS_SIE_EP_INT_EP1_MASK        (0x01u)
#define PD_USBFS_SIE_EP_INT_EP2_MASK        (0x02u)
#define PD_USBFS_SIE_EP_INT_EP3_MASK        (0x04u)
#define PD_USBFS_SIE_EP_INT_EP4_MASK        (0x08u)
#define PD_USBFS_SIE_EP_INT_EP5_MASK        (0x10u)
#define PD_USBFS_SIE_EP_INT_EP6_MASK        (0x20u)
#define PD_USBFS_SIE_EP_INT_EP7_MASK        (0x40u)
#define PD_USBFS_SIE_EP_INT_EP8_MASK        (0x80u)

#define PD_USBFS_PM_ACT_EN_FSUSB            PD_USBFS_USB__PM_ACT_MSK
#define PD_USBFS_PM_STBY_EN_FSUSB           PD_USBFS_USB__PM_STBY_MSK
#define PD_USBFS_PM_AVAIL_EN_FSUSBIO        (0x10u)

#define PD_USBFS_PM_USB_CR0_REF_EN          (0x01u)
#define PD_USBFS_PM_USB_CR0_PD_N            (0x02u)
#define PD_USBFS_PM_USB_CR0_PD_PULLUP_N     (0x04u)

#define PD_USBFS_USB_CLK_ENABLE             (0x01u)

#define PD_USBFS_DM_MASK                    PD_USBFS_Dm__0__MASK
#define PD_USBFS_DP_MASK                    PD_USBFS_Dp__0__MASK

#define PD_USBFS_DYN_RECONFIG_ENABLE        (0x01u)
#define PD_USBFS_DYN_RECONFIG_EP_SHIFT      (0x01u)
#define PD_USBFS_DYN_RECONFIG_RDY_STS       (0x10u)


#endif /*  CY_USBFS_PD_USBFS_H */


/* [] END OF FILE */
