/*******************************************************************************
* File Name: PD_USBFS_pm.c
* Version 2.80
*
* Description:
*  This file provides Suspend/Resume APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "project.h"
#include "PD_USBFS.h"
#include "PD_USBFS_pvt.h"


/***************************************
* Custom Declarations
***************************************/
/* `#START PM_CUSTOM_DECLARATIONS` Place your declaration here */

/* `#END` */


/***************************************
* Local data allocation
***************************************/

static PD_USBFS_BACKUP_STRUCT  PD_USBFS_backup;


#if(PD_USBFS_DP_ISR_REMOVE == 0u)

    /*******************************************************************************
    * Function Name: PD_USBFS_DP_Interrupt
    ********************************************************************************
    *
    * Summary:
    *  This Interrupt Service Routine handles DP pin changes for wake-up from
    *  the sleep mode.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    CY_ISR(PD_USBFS_DP_ISR)
    {
        /* `#START DP_USER_CODE` Place your code here */

        /* `#END` */

        /* Clears active interrupt */
        CY_GET_REG8(PD_USBFS_DP_INTSTAT_PTR);
    }

#endif /* (PD_USBFS_DP_ISR_REMOVE == 0u) */


/*******************************************************************************
* Function Name: PD_USBFS_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_USBFS_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: PD_USBFS_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_USBFS_RestoreConfig(void) 
{
    if(PD_USBFS_configuration != 0u)
    {
        PD_USBFS_ConfigReg();
    }
}


/*******************************************************************************
* Function Name: PD_USBFS_Suspend
********************************************************************************
*
* Summary:
*  This function disables the USBFS block and prepares for power down mode.
*
* Parameters:
*  None.
*
* Return:
*   None.
*
* Global variables:
*  PD_USBFS_backup.enable:  modified.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_USBFS_Suspend(void) 
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    if((CY_GET_REG8(PD_USBFS_CR0_PTR) & PD_USBFS_CR0_ENABLE) != 0u)
    {   /* USB block is enabled */
        PD_USBFS_backup.enableState = 1u;

        #if(PD_USBFS_EP_MM != PD_USBFS__EP_MANUAL)
            PD_USBFS_Stop_DMA(PD_USBFS_MAX_EP);     /* Stop all DMAs */
        #endif   /*  PD_USBFS_EP_MM != PD_USBFS__EP_MANUAL */

        /* Ensure USB transmit enable is low (USB_USBIO_CR0.ten). - Manual Transmission - Disabled */
        PD_USBFS_USBIO_CR0_REG &= (uint8)~PD_USBFS_USBIO_CR0_TEN;
        CyDelayUs(0u);  /*~50ns delay */

        /* Disable the USBIO by asserting PM.USB_CR0.fsusbio_pd_n(Inverted) and pd_pullup_hv(Inverted) high. */
        PD_USBFS_PM_USB_CR0_REG &=
                                (uint8)~(PD_USBFS_PM_USB_CR0_PD_N | PD_USBFS_PM_USB_CR0_PD_PULLUP_N);

        /* Disable the SIE */
        PD_USBFS_CR0_REG &= (uint8)~PD_USBFS_CR0_ENABLE;

        CyDelayUs(0u);  /* ~50ns delay */
        /* Store mode and Disable VRegulator*/
        PD_USBFS_backup.mode = PD_USBFS_CR1_REG & PD_USBFS_CR1_REG_ENABLE;
        PD_USBFS_CR1_REG &= (uint8)~PD_USBFS_CR1_REG_ENABLE;

        CyDelayUs(1u);  /* 0.5 us min delay */
        /* Disable the USBIO reference by setting PM.USB_CR0.fsusbio_ref_en.*/
        PD_USBFS_PM_USB_CR0_REG &= (uint8)~PD_USBFS_PM_USB_CR0_REF_EN;

        /* Switch DP and DM terminals to GPIO mode and disconnect 1.5k pullup*/
        PD_USBFS_USBIO_CR1_REG |= PD_USBFS_USBIO_CR1_IOMODE;

        /* Disable USB in ACT PM */
        PD_USBFS_PM_ACT_CFG_REG &= (uint8)~PD_USBFS_PM_ACT_EN_FSUSB;
        /* Disable USB block for Standby Power Mode */
        PD_USBFS_PM_STBY_CFG_REG &= (uint8)~PD_USBFS_PM_STBY_EN_FSUSB;
        CyDelayUs(1u); /* min  0.5us delay required */

    }
    else
    {
        PD_USBFS_backup.enableState = 0u;
    }

    CyExitCriticalSection(enableInterrupts);

    /* Set the DP Interrupt for wake-up from sleep mode. */
    #if(PD_USBFS_DP_ISR_REMOVE == 0u)
        (void) CyIntSetVector(PD_USBFS_DP_INTC_VECT_NUM, &PD_USBFS_DP_ISR);
        CyIntSetPriority(PD_USBFS_DP_INTC_VECT_NUM, PD_USBFS_DP_INTC_PRIOR);
        CyIntClearPending(PD_USBFS_DP_INTC_VECT_NUM);
        CyIntEnable(PD_USBFS_DP_INTC_VECT_NUM);
    #endif /* (PD_USBFS_DP_ISR_REMOVE == 0u) */
}


/*******************************************************************************
* Function Name: PD_USBFS_Resume
********************************************************************************
*
* Summary:
*  This function enables the USBFS block after power down mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  PD_USBFS_backup - checked.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_USBFS_Resume(void) 
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    if(PD_USBFS_backup.enableState != 0u)
    {
        #if(PD_USBFS_DP_ISR_REMOVE == 0u)
            CyIntDisable(PD_USBFS_DP_INTC_VECT_NUM);
        #endif /*  PD_USBFS_DP_ISR_REMOVE */

        /* Enable USB block */
        PD_USBFS_PM_ACT_CFG_REG |= PD_USBFS_PM_ACT_EN_FSUSB;
        /* Enable USB block for Standby Power Mode */
        PD_USBFS_PM_STBY_CFG_REG |= PD_USBFS_PM_STBY_EN_FSUSB;
        /* Enable core clock */
        PD_USBFS_USB_CLK_EN_REG |= PD_USBFS_USB_CLK_ENABLE;

        /* Enable the USBIO reference by setting PM.USB_CR0.fsusbio_ref_en.*/
        PD_USBFS_PM_USB_CR0_REG |= PD_USBFS_PM_USB_CR0_REF_EN;
        /* The reference will be available ~40us after power restored */
        CyDelayUs(40u);
        /* Return VRegulator*/
        PD_USBFS_CR1_REG |= PD_USBFS_backup.mode;
        CyDelayUs(0u);  /*~50ns delay */
        /* Enable USBIO */
        PD_USBFS_PM_USB_CR0_REG |= PD_USBFS_PM_USB_CR0_PD_N;
        CyDelayUs(2u);
        /* Set the USBIO pull-up enable */
        PD_USBFS_PM_USB_CR0_REG |= PD_USBFS_PM_USB_CR0_PD_PULLUP_N;

        /* Re-init Arbiter configuration for DMA transfers */
        #if(PD_USBFS_EP_MM != PD_USBFS__EP_MANUAL)
            /* Usb arb interrupt enable */
            PD_USBFS_ARB_INT_EN_REG = PD_USBFS_ARB_INT_MASK;
            #if(PD_USBFS_EP_MM == PD_USBFS__EP_DMAMANUAL)
                PD_USBFS_ARB_CFG_REG = PD_USBFS_ARB_CFG_MANUAL_DMA;
            #endif   /*  PD_USBFS_EP_MM == PD_USBFS__EP_DMAMANUAL */
            #if(PD_USBFS_EP_MM == PD_USBFS__EP_DMAAUTO)
                /*Set cfg cmplt this rises DMA request when the full configuration is done */
                PD_USBFS_ARB_CFG_REG = PD_USBFS_ARB_CFG_AUTO_DMA | PD_USBFS_ARB_CFG_AUTO_MEM;
            #endif   /*  PD_USBFS_EP_MM == PD_USBFS__EP_DMAAUTO */
        #endif   /*  PD_USBFS_EP_MM != PD_USBFS__EP_MANUAL */

        /* STALL_IN_OUT */
        CY_SET_REG8(PD_USBFS_EP0_CR_PTR, PD_USBFS_MODE_STALL_IN_OUT);
        /* Enable the SIE with a last address */
        PD_USBFS_CR0_REG |= PD_USBFS_CR0_ENABLE;
        CyDelayCycles(1u);
        /* Finally, Enable d+ pullup and select iomode to USB mode*/
        CY_SET_REG8(PD_USBFS_USBIO_CR1_PTR, PD_USBFS_USBIO_CR1_USBPUEN);

        /* Restore USB register settings */
        PD_USBFS_RestoreConfig();
    }

    CyExitCriticalSection(enableInterrupts);
}


/* [] END OF FILE */
