//=====================================================================
//
//	j1Console.c - support routines for Console
//
//=====================================================================

//=====================================================================
//
// Copyright (c) 2015 Joshua 1 Systems Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
//    1. Redistributions of source code must retain the above copyright notice, this list of
//       conditions and the following disclaimer.
//
//    2. Redistributions in binary form must reproduce the above copyright notice, this list
//       of conditions and the following disclaimer in the documentation and/or other materials
//       provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY JOSHUA 1 SYSTEMS INC. "AS IS" AND ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
// ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// The views and conclusions contained in the software and documentation are those of the
// authors and should not be interpreted as representing official policies, either expressed
// or implied, of Joshua 1 Systems Inc.
//
//=====================================================================

//#include "HardwareProfile.h"

//#include "j1Console.h"
//#include "j1XML.h"
//#include "j1Hex.h"

#include "PD_j1Console.h"
#include "PD_ConsoleCmd.h"

//---------------------------------------------------------------------
//
//	j1Console_Start() - init the console logic
//
//---------------------------------------------------------------------

void j1Console_Start(void)
{
	j1QueueInit(j1ConsoleRxQueue);
	j1QueueInit(j1ConsoleTxQueue);

	j1ConsoleCmd.bfr[0]	= 0;
	j1ConsoleCmd.bfrPtr	= j1ConsoleCmd.bfr;
	j1ConsoleCmd.bfrCnt	= 0;
	j1ConsoleCmd.bfrRdy	= false;
	j1ConsoleCmd.first	= true;
	j1ConsoleCmd.debug	= false;
	j1ConsoleCmd.escape	= false;
}

//---------------------------------------------------------------------
//
//	j1Console_QueueRx() - queue up a buffer of bytes to the console rx
//
//---------------------------------------------------------------------

bool j1Console_QueueRx(uint8 *bfr, uint16 bfrCnt)
{
	uint8	c;

	while (bfrCnt--)
	{
		c = *bfr++;
		if (j1QueueFull(j1ConsoleRxQueue)) return false;
		j1QueueAdd(j1ConsoleRxQueue, c);
	}

	return true;
}

//---------------------------------------------------------------------
//
//	j1Console_DeQueueTx() - fetch out a block of bytes from the console tx
//
//---------------------------------------------------------------------

bool j1Console_DeQueueTx(uint8 *bfr, uint16 bfrSize, uint16 *deQueued)
{
	uint16	bfrCnt;

	if (j1QueueEmpty(j1ConsoleTxQueue))
	{
		*deQueued = 0;
		return false;
	}

	bfrCnt = 0;

	while (bfrCnt < bfrSize && j1QueueAvail(j1ConsoleTxQueue))
	{
		*bfr++ = j1QueueGet(j1ConsoleTxQueue);
		bfrCnt++;
	}

	*deQueued = bfrCnt;
	return true;
}

//---------------------------------------------------------------------
//
//	j1Console_Tasks() - process loop console tasks
//
//---------------------------------------------------------------------

void j1Console_Tasks(void)
{
	j1Console_ProcessRx();
	PD_ConsoleCmd_Tasks();
}

//---------------------------------------------------------------------
//
//	j1Console_ProcessRx() - process the rx queue
//
//---------------------------------------------------------------------

void j1Console_ProcessRx(void)
{
	char	c;


	if (!j1ConsoleCmd.bfrRdy)
	{
		while (j1QueueAvail(j1ConsoleRxQueue))
		{
			c = j1QueueGet(j1ConsoleRxQueue);

			if (j1ConsoleCmd.escape)
			{
				switch (j1ConsoleCmd.escState)
				{
				case j1CONSOLE_CMD_ESC_ESC:
					switch (c)
					{
					case '[':
						j1ConsoleCmd.escState = j1CONSOLE_CMD_ESC_BRKT;
						break;

					default:
						j1Console_Put(0x07);
						j1ConsoleCmd.escape = false;
					}
					break;

				case j1CONSOLE_CMD_ESC_BRKT:
				
					switch (c)
					{
					case 'A':
						if (j1ConsoleCmd.bfrCnt == 0 && strlen(j1ConsoleCmd.bfr))
						{
							j1Console_PutString(j1ConsoleCmd.bfr);
							j1ConsoleCmd.bfrCnt = strlen(j1ConsoleCmd.bfr);
							j1ConsoleCmd.bfrPtr = j1ConsoleCmd.bfr + j1ConsoleCmd.bfrCnt;
						}
						else { j1Console_Put(0x07); }
						break;

					default:
						j1Console_Put(0x07);
					}

					j1ConsoleCmd.escape = false;
					break;
				}
			}

			else
			{
				switch (c)
				{
				case 0x08:
					if (j1ConsoleTxQueue.count < j1QueueSize(j1ConsoleTxQueue) - 4)
					{
						if (j1ConsoleCmd.bfrCnt)
						{
							j1Console_Put(0x08);
							j1Console_Put(' ' );
							j1Console_Put(0x08);
							j1ConsoleCmd.bfrPtr--;
							j1ConsoleCmd.bfrCnt--;
						}

						else { j1Console_Put(0x07); }
					}
					else
					{
						j1Console_Put(0x07);
					}
					break;

				case 0x0A:
					j1Console_PutCRLF();
					*j1ConsoleCmd.bfrPtr	= 0x00;
					j1ConsoleCmd.bfrRdy		= true;
					j1ConsoleCmd.first		= true;
					break;

				case 0x0D:
					j1Console_PutCRLF();
					*j1ConsoleCmd.bfrPtr	= 0x00;
					j1ConsoleCmd.bfrRdy		= true;
					break;

				case 0x1B:
					j1ConsoleCmd.escape		= true;
					j1ConsoleCmd.escState	= j1CONSOLE_CMD_ESC_ESC;
					break;

				default:
					if (c < ' ')
					{
						j1Console_Put(0x07);
					}
					else
					{
						if (j1ConsoleCmd.bfrCnt < j1CONSOLE_CMD_BFR_MAX)
						{
							*j1ConsoleCmd.bfrPtr++ = c;
							j1ConsoleCmd.bfrCnt++;

							j1Console_Put(c);
						}
					}
				}
			}
		}
	}
}

//---------------------------------------------------------------------
//
//	j1Console_Put() / j1Console_PutString()
//	j1Console_PutBYTE() / j1Console_PutWORD()
//	j1Console_PutDWORD()
//	j1Console_PutCRLF()
//
//		functions to put (add to queue) data to console tx
//
//---------------------------------------------------------------------

bool j1Console_Put(char valueBYTE)
{
	if (j1QueueFull(j1ConsoleTxQueue)) return false;

	j1QueueAdd(j1ConsoleTxQueue, valueBYTE);

	return true;
}

bool j1Console_PutString(char *valueString)
{
	if (strlen(valueString) > j1QueueSize(j1ConsoleTxQueue) - j1QueueCount(j1ConsoleTxQueue)) return false;

	j1QueueAddString(j1ConsoleTxQueue, valueString);

	return true;
}

bool j1Console_PutHEXBYTE(uint8 valueBYTE)
{
	char	bfr[3];
	
	memset(bfr, 0, sizeof(bfr));
//	j1BYTE_to_Hex(bfr, sizeof(bfr), valueBYTE);
	return j1Console_PutString(bfr);
}

bool j1Console_PutHEXWORD(uint16 valueWORD)
{
	char	bfr[5];
	
	memset(bfr, 0, sizeof(bfr));
//	j1WORD_to_Hex(bfr, sizeof(bfr), valueWORD);
	return j1Console_PutString(bfr);
}

bool j1Console_PutHEXDWORD(uint32 valueDWORD)
{
	char	bfr[9];

	memset(bfr, 0, sizeof(bfr));
//	j1DWORD_to_Hex(bfr, sizeof(bfr), valueDWORD);
	return j1Console_PutString(bfr);
}

bool j1Console_PutBYTE(uint8 valueBYTE)
{
	char	bfr[4];
	
	memset(bfr, 0, sizeof(bfr));
//	j1_uitoa(valueBYTE, bfr);
	return j1Console_PutString(bfr);
}

bool j1Console_PutWORD(uint16 valueWORD)
{
	char	bfr[8];
	
	memset(bfr, 0, sizeof(bfr));
//	j1_uitoa(valueWORD, bfr);
	return j1Console_PutString(bfr);
}

bool j1Console_PutDWORD(uint32 valueDWORD)
{
	char	bfr[16];

	memset(bfr, 0, sizeof(bfr));
//	j1_ultoa(valueDWORD, bfr);
	return j1Console_PutString(bfr);
}

bool j1Console_PutCRLF(void)
{
	if (j1QueueFull(j1ConsoleTxQueue)) return false;
	j1QueueAdd(j1ConsoleTxQueue, 0x0D);
	if (j1QueueFull(j1ConsoleTxQueue)) return false;
	j1QueueAdd(j1ConsoleTxQueue, 0x0A);
	return true;
}

//---------------------------------------------------------------------
//
//	j1Console_DumpCmd() - common dump command code
//
//---------------------------------------------------------------------

bool j1Console_DumpCmd(j1XML_ELEMENT *cmd)
{
/***
	BYTE	*memPtr;
	DWORD	memLen, value;
	char	*aNamePtr, *aValuePtr;
	int		aEntrySize, i, col;
	BOOL	valid;
//	MEMORY_MAP_ENTRY	const *memEntry;
	char	c;

	struct
	{
		char	addressHex[9];
		struct
		{
			char	hex[3];
		} bytes[16];
		char	_space2;
		char	asciiBfr[16];
		char	cr;
		char	lf;
		char	eos;
	} lineBfr;

	if (strcasecmp(cmd->eNameBfr, "d")) return false;

	memPtr = 0;
	memLen = 0x100;

	aEntrySize	= cmd->aNameSize + cmd->aValueSize;
	aNamePtr	= cmd->aBfr;
	aValuePtr	= aNamePtr + cmd->aNameSize;

	for (i = 0; i < cmd->aCount; i++)
	{
		value = j1_strtoul(aValuePtr, NULL, 16);

		if (strcasecmp(aNamePtr, "s") == 0) memPtr = (BYTE *) value;
		if (strcasecmp(aNamePtr, "l") == 0) memLen = value;

		aNamePtr  += aEntrySize;
		aValuePtr += aEntrySize;
	}

	valid = false;

//	for (memEntry = MemoryMap, i = 0; i < MemoryMap_size; i++, memEntry++)
//	{
//		if (memEntry->baseAddress <= (DWORD) memPtr && (DWORD) memPtr <= memEntry->endAddress)
//		{
//			if ((DWORD) memPtr + memLen > memEntry->endAddress) memLen = (BYTE *) memEntry->endAddress - memPtr + 1;
//			valid = true;
//			break;
//		}
//	}
	valid = true;

	if (valid) if (0 < memLen && memLen <= 0x100)
	{
		for (i = 0; i < memLen; i++)
		{
			col = (DWORD) memPtr & 0xf;
			if (i == 0 || col == 0)
			{
				if (i) j1Console_PutString((char *) &lineBfr);

				memset(&lineBfr, ' ', sizeof(lineBfr));
				lineBfr.cr = 13;
				lineBfr.lf = 10;
				lineBfr.eos = 0;
				j1DWORD_to_Hex(lineBfr.addressHex, sizeof(lineBfr.addressHex), (DWORD) memPtr & 0xfffffff0);
				lineBfr.addressHex[8] = ' ';
			}

			c = *memPtr++;
			j1BYTE_to_Hex(lineBfr.bytes[col].hex, sizeof(lineBfr.bytes[col].hex), c);
			lineBfr.bytes[col].hex[2] = ' ';
			if (c < 0x20 || 0x7e < c) c = '.';
			lineBfr.asciiBfr[col] = c;
		}

		j1Console_PutString((char *) &lineBfr);
		return true;
	}
***/
	return false;
}
