//=====================================================================
//
//	PD_j1Get.c - j1sys device independent get lib
//
//	version 1.0 - 16 dec 2013
//
//=====================================================================

//=====================================================================
//
// Copyright (c) 2015 Joshua 1 Systems Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
//    1. Redistributions of source code must retain the above copyright notice, this list of
//       conditions and the following disclaimer.
//
//    2. Redistributions in binary form must reproduce the above copyright notice, this list
//       of conditions and the following disclaimer in the documentation and/or other materials
//       provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY JOSHUA 1 SYSTEMS INC. "AS IS" AND ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
// ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// The views and conclusions contained in the software and documentation are those of the
// authors and should not be interpreted as representing official policies, either expressed
// or implied, of Joshua 1 Systems Inc.
//
//=====================================================================

#include <project.h>

//---------------------------------------------------------------------
//	j1Get_Start() - init the control
//---------------------------------------------------------------------

bool j1Get_Start(j1Get_CTRL *getC, void *read, void *deviceCtrl)
{
	memset(getC, 0, sizeof(j1Get_CTRL));
	
	getC->Read			= read;
	getC->deviceCtrl	= deviceCtrl;
	
	return true;
}

//---------------------------------------------------------------------
//	j1Get_Char() - get a char buffered using control
//---------------------------------------------------------------------

bool j1Get_Char(j1Get_CTRL *getC, char *c)
{
	if (getC->eofReached) return false;
	
	if (getC->readBfrCnt == 0)
	{
		if (!getC->Read(getC->deviceCtrl, getC->readBfr, sizeof(getC->readBfr), &(getC->readBfrCnt)))
		{
			getC->eofReached = true;
			return false;
		}
		
		getC->readBfrPtr = getC->readBfr;
	}
	
	*c = *(getC->readBfrPtr)++;
	getC->readBfrCnt--;
	
	return true;
}

//---------------------------------------------------------------------
//	j1Get_Field() - get a field buffered using control
//---------------------------------------------------------------------

bool j1Get_Field(j1Get_CTRL *getC, char *field, uint16 fieldSize)
{
	return false;
}

//---------------------------------------------------------------------
//	j1Get_Line() - get a line buffered using control
//---------------------------------------------------------------------

bool j1Get_Line(j1Get_CTRL *getC, char *lineBfr, uint16 lineSize, uint16 *lineLen)
{
	char	c;
	uint16	lineCnt;
	char	*linePtr;
	
	lineCnt	= 0;
	linePtr	= lineBfr;
	
	while (lineCnt < lineSize)
	{
		if (!j1Get_Char(getC, &c)) break;
		
		if (c == 0x0d)
		{
			if (j1Get_Char(getC, &c));
			 if (c == 0x0a)
			{
				*linePtr = 0;
				*lineLen = lineCnt;
				return true;
			}
			break;
		}
		
		*linePtr++ = c;
		lineCnt++;
	}
	
	return false;
}
