//=====================================================================
//
//	j1UBL_XML.c - program file for j1UBL XML
//
//=====================================================================

//=====================================================================
//
// Copyright (c) 2015 Joshua 1 Systems Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
//    1. Redistributions of source code must retain the above copyright notice, this list of
//       conditions and the following disclaimer.
//
//    2. Redistributions in binary form must reproduce the above copyright notice, this list
//       of conditions and the following disclaimer in the documentation and/or other materials
//       provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY JOSHUA 1 SYSTEMS INC. "AS IS" AND ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
// ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// The views and conclusions contained in the software and documentation are those of the
// authors and should not be interpreted as representing official policies, either expressed
// or implied, of Joshua 1 Systems Inc.
//
//=====================================================================

//#include "PD_j1UBL_XML_main.h"
#include <project.h>

//---------------------------------------------------------------------
//
//	ConfigXML_Validate()
//
//---------------------------------------------------------------------

j1XML_RESULT j1UBL_XML_Validate(j1XML_ELEMENT *element, j1UBL_TOKEN_XXX *tokenXXX, int depth, uint16 *eStack)
{
	int			aIdx, attrID;
	char		*valTxt;
	bool		valid = false;

	memset(tokenXXX, 0, sizeof(j1UBL_TOKEN_XXX));

	switch (element->eID)
	{
	//---------------------------------------------------------------
	// j1UBL - allowed as base level only!!, allowed as empty
	//---------------------------------------------------------------
	case j1UBL_XML_UBL:
		switch (element->eType)
		{
		case j1XML_ETYPE_EMPTY:
			if (depth == 0) valid = true;

			tokenXXX->j1UBL.token.bits.elem = j1UBL_TOKEN_ELEM_UBL;
			tokenXXX->j1UBL.token.bits.etyp = j1UBL_TOKEN_ETYP_EMPTY;

			if (valid)
			{
				for (aIdx = 0; aIdx < element->aCount; aIdx++)
				{
					attrID = element->aIDTbl[aIdx];
					valTxt = &element->aBfr[aIdx * (element->aNameSize + element->aValueSize) + element->aNameSize];

					switch (attrID)
					{
					case 0:
						break;
	
					case j1UBL_XML_ATTR_HOST:
						tokenXXX->j1UBL.attr1.bits.host = 1;
						strcpy(tokenXXX->j1UBL.host, valTxt);
						break;

#if !PD_j1UBL_XML_PARAM_ETH_ENABLED
					case j1UBL_XML_ATTR_MAC:
						tokenXXX->j1UBL.attr1.bits.mac = 1;
						tokenXXX->j1UBL.mac = element->vTbl[aIdx];
						break;
#else
					case j1UBL_XML_ATTR_AN:
						tokenXXX->j1UBL.attr1.bits.an = 1;
						tokenXXX->j1UBL.an = (BYTE) element->vTbl[aIdx];
						break;

					case j1UBL_XML_ATTR_IP:
						tokenXXX->j1UBL.attr1.bits.ip = 1;
						tokenXXX->j1UBL.ip.dwIP = element->vTbl[aIdx];
						break;

					case j1UBL_XML_ATTR_NM:
						tokenXXX->j1UBL.attr1.bits.nm = 1;
						tokenXXX->j1UBL.nm.dwIP = element->vTbl[aIdx];
						break;

					case j1UBL_XML_ATTR_GW:
						tokenXXX->j1UBL.attr1.bits.gw = 1;
						tokenXXX->j1UBL.gw.dwIP = element->vTbl[aIdx];
						break;

					case j1UBL_XML_ATTR_DNS1:
						tokenXXX->j1UBL.attr1.bits.dns1 = 1;
						tokenXXX->j1UBL.dns1.dwIP = element->vTbl[aIdx];
						break;

					case j1UBL_XML_ATTR_DNS2:
						tokenXXX->j1UBL.attr1.bits.dns2 = 1;
						tokenXXX->j1UBL.dns2.dwIP = element->vTbl[aIdx];
						break;
#endif
					case j1UBL_XML_ATTR_PWD:
						tokenXXX->j1UBL.attr2.bits.pwd = 1;
						strcpy(tokenXXX->j1UBL.pwd, valTxt);
						break;
#if PD_j1UBL_XML_PARAM_XP_ENABLED
					case j1UBL_XML_ATTR_XP:
						tokenXXX->j1UBL.attr2.bits.xp = 1;
						strcpy(tokenXXX->j1UBL.xp, valTxt);
						break;
#endif

#if PD_j1UBL_XML_PARAM_HY28B_ENABLED
					case j1UBL_XML_ATTR_HY28B:
						tokenXXX->j1UBL.attr2.bits.hy28b = 1;
						strcpy(tokenXXX->j1UBL.hy28b, valTxt);
						break;
#endif

					default:
						valid = false;
					}
				}
			}

			if (valid)
			{
#if PD_j1UBL_XML_PARAM_ETH_ENABLED
				if (tokenXXX->j1UBL.attr1.bits.an)
				{
					if (tokenXXX->j1UBL.attr1.bits.ip  ) valid = false;
					if (tokenXXX->j1UBL.attr1.bits.nm  ) valid = false;
					if (tokenXXX->j1UBL.attr1.bits.gw  ) valid = false;
					if (tokenXXX->j1UBL.attr1.bits.dns1) valid = false;
					if (tokenXXX->j1UBL.attr1.bits.dns2) valid = false;
					
					if (tokenXXX->j1UBL.an != 2 && tokenXXX->j1UBL.an != 10) valid = false;
				}
				else
				{
					if (!tokenXXX->j1UBL.attr1.bits.ip)
					{
						tokenXXX->j1UBL.attr1.bits.ip = 1;
						tokenXXX->j1UBL.ip.dwIP = 0x0a0a0a0a;
					}
					
					if (!tokenXXX->j1UBL.attr1.bits.nm)
					{
						tokenXXX->j1UBL.attr1.bits.nm = 1;
						tokenXXX->j1UBL.nm.dwIP = 0x000000ff;
					}
				}
#endif
			}

			if (valid) return j1XML_RESULT_OK;
			break;
			
		default:
			break;
		}
		
		break;

	}

	return j1XML_RESULT_VALIDATE_INVALID;
}

//---------------------------------------------------------------------
//
//	j1UBL_XML_EraseXML() - erase it all
//
//---------------------------------------------------------------------

j1XML_RESULT j1UBL_XML_EraseXML()
{
	uint8		xmlBfr[256];
	uint8		eeBfr[CY_EEPROM_SIZEOF_ROW];
	uint8		*xmlBfrPtr;
	uint16		xmlBfrCnt;
	uint16		eeRowNum;
	uint16		rowIndex;
	cystatus	cyret;
			
	memset(xmlBfr, 0, sizeof(xmlBfr));
	
	CyEEPROM_Start();
	CySetTemp();
	CyDelay(1);
			
	eeRowNum	= 0x40 * (CY_EEPROM_SIZEOF_ARRAY / CY_EEPROM_SIZEOF_ROW);
	rowIndex = 0;
	xmlBfrCnt = strlen((char *) xmlBfr) + 1;
	xmlBfrPtr = xmlBfr;
			
	while (xmlBfrCnt)
	{
		memset(eeBfr, 0, sizeof(eeBfr));
		for (rowIndex = 0; rowIndex < CY_EEPROM_SIZEOF_ROW; rowIndex++)
		{
			if (xmlBfrCnt == 0) break;
			eeBfr[rowIndex] = *xmlBfrPtr++;
			xmlBfrCnt--;
		}
				
		// write the row
		cyret = CyWriteRowFull(eeRowNum / (CY_EEPROM_SIZEOF_ARRAY / CY_EEPROM_SIZEOF_ROW),
							   eeRowNum % (CY_EEPROM_SIZEOF_ARRAY / CY_EEPROM_SIZEOF_ROW),
							   eeBfr, CY_EEPROM_SIZEOF_ROW);

		if (cyret != CYRET_SUCCESS) return j1XML_RESULT_WRITE_ERROR;
		eeRowNum++;
	}
			
	return j1XML_RESULT_OK;
}

//---------------------------------------------------------------------
//
//	j1UBL_XML_WriteXML() - write it all out to flash
//
//---------------------------------------------------------------------

j1XML_RESULT j1UBL_XML_WriteXML(j1UBL_TOKEN_XXX *tokenXXX)
{
	uint32			offset = 0, newOffset;
	j1XML_RESULT	result;

	j1XML_ELEMENT_GEN(element,  8, 12, 8, 32);
	uint16		aCnt;

	uint8		xmlBfr[256];
	uint8		eeBfr[CY_EEPROM_SIZEOF_ROW];
	uint8		*xmlBfrPtr;
	uint16		xmlBfrCnt;
	uint16		eeRowNum;
	uint16		rowIndex;
	cystatus	cyret;
			
	memset(xmlBfr, 0, sizeof(xmlBfr));
	j1XML_Open(j1XML_IOMODE_WRITE_MEM, (uint32) xmlBfr, sizeof(xmlBfr) - 1);

	j1XML_SetElementName(&element, &j1UBL_XML_ubl);
	element.eType = j1XML_ETYPE_EMPTY;

	aCnt = 0;

	if (tokenXXX->j1UBL.attr1.bits.host)	{ j1XML_SetAttribute(&element, &aCnt,   tokenXXX->j1UBL.host    , &j1UBL_XML_HOST);  }
#if !PD_j1UBL_XML_PARAM_ETH_ENABLED
	if (tokenXXX->j1UBL.attr1.bits.mac)		{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.mac)    , &j1UBL_XML_MAC);   }
#else
	if (tokenXXX->j1UBL.attr1.bits.an)		{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.an)     , &j1UBL_XML_AN);    }
	if (tokenXXX->j1UBL.attr1.bits.ip)		{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.ip)     , &j1UBL_XML_IP);    }
	if (tokenXXX->j1UBL.attr1.bits.nm)		{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.nm)     , &j1UBL_XML_NM);    }
	if (tokenXXX->j1UBL.attr1.bits.gw)		{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.gw)     , &j1UBL_XML_GW);    }
	if (tokenXXX->j1UBL.attr1.bits.dns1)	{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.dns1)   , &j1UBL_XML_DNS1);  }
	if (tokenXXX->j1UBL.attr1.bits.dns2)	{ j1XML_SetAttribute(&element, &aCnt, &(tokenXXX->j1UBL.dns2)   , &j1UBL_XML_DNS2);  }
#endif
	if (tokenXXX->j1UBL.attr2.bits.pwd)		{ j1XML_SetAttribute(&element, &aCnt,   tokenXXX->j1UBL.pwd     , &j1UBL_XML_PWD);   }
#if PD_j1UBL_XML_PARAM_XP_ENABLED
	if (tokenXXX->j1UBL.attr2.bits.xp)		{ j1XML_SetAttribute(&element, &aCnt,   tokenXXX->j1UBL.xp      , &j1UBL_XML_XP);    }
#endif
#if PD_j1UBL_XML_PARAM_HY28B_ENABLED
	if (tokenXXX->j1UBL.attr2.bits.hy28b)	{ j1XML_SetAttribute(&element, &aCnt,   tokenXXX->j1UBL.hy28b   , &j1UBL_XML_HY28B); }
#endif

	result = j1XML_WriteElement(offset, 0, &element, &newOffset);
	offset = newOffset;
	
//	j1Put_SetTextRowCol(__pC, 4, 0);
//	j1Put_String(__pC, (char *) xmlBfr);
	
	if (result != j1XML_RESULT_OK) return result;
	
	CyEEPROM_Start();
	CySetTemp();
	CyDelay(1);
			
	eeRowNum	= 0x40 * (CY_EEPROM_SIZEOF_ARRAY / CY_EEPROM_SIZEOF_ROW);
	rowIndex = 0;
	xmlBfrCnt = strlen((char *) xmlBfr) + 1;
	xmlBfrPtr = xmlBfr;
			
	while (xmlBfrCnt)
	{
		memset(eeBfr, 0, sizeof(eeBfr));
		for (rowIndex = 0; rowIndex < CY_EEPROM_SIZEOF_ROW; rowIndex++)
		{
			if (xmlBfrCnt == 0) break;
			eeBfr[rowIndex] = *xmlBfrPtr++;
			xmlBfrCnt--;
		}
				
		// write the row
		cyret = CyWriteRowFull(eeRowNum / (CY_EEPROM_SIZEOF_ARRAY / CY_EEPROM_SIZEOF_ROW),
							   eeRowNum % (CY_EEPROM_SIZEOF_ARRAY / CY_EEPROM_SIZEOF_ROW),
							   eeBfr, CY_EEPROM_SIZEOF_ROW);

		if (cyret != CYRET_SUCCESS) return j1XML_RESULT_WRITE_ERROR;
		eeRowNum++;
	}
			
	return j1XML_RESULT_OK;
}
