/*******************************************************************************
* File Name: PD_microSD_iSPIM.c
* Version 2.50
*
* Description:
*  This file provides all API functionality of the SPI Master component.
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PD_microSD_iSPIM_PVT.h"

#if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)
    volatile uint8 PD_microSD_iSPIM_txBuffer[PD_microSD_iSPIM_TX_BUFFER_SIZE];
    volatile uint8 PD_microSD_iSPIM_txBufferFull;
    volatile uint8 PD_microSD_iSPIM_txBufferRead;
    volatile uint8 PD_microSD_iSPIM_txBufferWrite;
#endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */

#if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)
    volatile uint8 PD_microSD_iSPIM_rxBuffer[PD_microSD_iSPIM_RX_BUFFER_SIZE];
    volatile uint8 PD_microSD_iSPIM_rxBufferFull;
    volatile uint8 PD_microSD_iSPIM_rxBufferRead;
    volatile uint8 PD_microSD_iSPIM_rxBufferWrite;
#endif /* (PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */

uint8 PD_microSD_iSPIM_initVar = 0u;

volatile uint8 PD_microSD_iSPIM_swStatusTx;
volatile uint8 PD_microSD_iSPIM_swStatusRx;


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_Init
********************************************************************************
*
* Summary:
*  Inits/Restores default SPIM configuration provided with customizer.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  When this function is called it initializes all of the necessary parameters
*  for execution. i.e. setting the initial interrupt mask, configuring the
*  interrupt service routine, configuring the bit-counter parameters and
*  clearing the FIFO and Status Register.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_Init(void) 
{
    /* Initialize the Bit counter */
    PD_microSD_iSPIM_COUNTER_PERIOD_REG = PD_microSD_iSPIM_BITCTR_INIT;

    /* Init TX ISR  */
    #if(0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED)
        CyIntDisable         (PD_microSD_iSPIM_TX_ISR_NUMBER);
        CyIntSetPriority     (PD_microSD_iSPIM_TX_ISR_NUMBER,  PD_microSD_iSPIM_TX_ISR_PRIORITY);
        (void) CyIntSetVector(PD_microSD_iSPIM_TX_ISR_NUMBER, &PD_microSD_iSPIM_TX_ISR);
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED) */

    /* Init RX ISR  */
    #if(0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED)
        CyIntDisable         (PD_microSD_iSPIM_RX_ISR_NUMBER);
        CyIntSetPriority     (PD_microSD_iSPIM_RX_ISR_NUMBER,  PD_microSD_iSPIM_RX_ISR_PRIORITY);
        (void) CyIntSetVector(PD_microSD_iSPIM_RX_ISR_NUMBER, &PD_microSD_iSPIM_RX_ISR);
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED) */

    /* Clear any stray data from the RX and TX FIFO */
    PD_microSD_iSPIM_ClearFIFO();

    #if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)
        PD_microSD_iSPIM_rxBufferFull  = 0u;
        PD_microSD_iSPIM_rxBufferRead  = 0u;
        PD_microSD_iSPIM_rxBufferWrite = 0u;
    #endif /* (PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */

    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)
        PD_microSD_iSPIM_txBufferFull  = 0u;
        PD_microSD_iSPIM_txBufferRead  = 0u;
        PD_microSD_iSPIM_txBufferWrite = 0u;
    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */

    (void) PD_microSD_iSPIM_ReadTxStatus(); /* Clear Tx status and swStatusTx */
    (void) PD_microSD_iSPIM_ReadRxStatus(); /* Clear Rx status and swStatusRx */

    /* Configure TX and RX interrupt mask */
    PD_microSD_iSPIM_TX_STATUS_MASK_REG = PD_microSD_iSPIM_TX_INIT_INTERRUPTS_MASK;
    PD_microSD_iSPIM_RX_STATUS_MASK_REG = PD_microSD_iSPIM_RX_INIT_INTERRUPTS_MASK;
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_Enable
********************************************************************************
*
* Summary:
*  Enable SPIM component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void PD_microSD_iSPIM_Enable(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    PD_microSD_iSPIM_COUNTER_CONTROL_REG |= PD_microSD_iSPIM_CNTR_ENABLE;
    PD_microSD_iSPIM_TX_STATUS_ACTL_REG  |= PD_microSD_iSPIM_INT_ENABLE;
    PD_microSD_iSPIM_RX_STATUS_ACTL_REG  |= PD_microSD_iSPIM_INT_ENABLE;
    CyExitCriticalSection(enableInterrupts);

    #if(0u != PD_microSD_iSPIM_INTERNAL_CLOCK)
        PD_microSD_iSPIM_IntClock_Enable();
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_CLOCK) */

    PD_microSD_iSPIM_EnableTxInt();
    PD_microSD_iSPIM_EnableRxInt();
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_Start
********************************************************************************
*
* Summary:
*  Initialize and Enable the SPI Master component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  PD_microSD_iSPIM_initVar - used to check initial configuration, modified on
*  first function call.
*
* Theory:
*  Enable the clock input to enable operation.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_Start(void) 
{
    if(0u == PD_microSD_iSPIM_initVar)
    {
        PD_microSD_iSPIM_Init();
        PD_microSD_iSPIM_initVar = 1u;
    }

    PD_microSD_iSPIM_Enable();
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_Stop
********************************************************************************
*
* Summary:
*  Disable the SPI Master component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the clock input to enable operation.
*
*******************************************************************************/
void PD_microSD_iSPIM_Stop(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    PD_microSD_iSPIM_TX_STATUS_ACTL_REG &= ((uint8) ~PD_microSD_iSPIM_INT_ENABLE);
    PD_microSD_iSPIM_RX_STATUS_ACTL_REG &= ((uint8) ~PD_microSD_iSPIM_INT_ENABLE);
    CyExitCriticalSection(enableInterrupts);

    #if(0u != PD_microSD_iSPIM_INTERNAL_CLOCK)
        PD_microSD_iSPIM_IntClock_Disable();
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_CLOCK) */

    PD_microSD_iSPIM_DisableTxInt();
    PD_microSD_iSPIM_DisableRxInt();
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_EnableTxInt
********************************************************************************
*
* Summary:
*  Enable internal Tx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal Tx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void PD_microSD_iSPIM_EnableTxInt(void) 
{
    #if(0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED)
        CyIntEnable(PD_microSD_iSPIM_TX_ISR_NUMBER);
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_EnableRxInt
********************************************************************************
*
* Summary:
*  Enable internal Rx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal Rx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void PD_microSD_iSPIM_EnableRxInt(void) 
{
    #if(0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED)
        CyIntEnable(PD_microSD_iSPIM_RX_ISR_NUMBER);
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_DisableTxInt
********************************************************************************
*
* Summary:
*  Disable internal Tx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal Tx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void PD_microSD_iSPIM_DisableTxInt(void) 
{
    #if(0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED)
        CyIntDisable(PD_microSD_iSPIM_TX_ISR_NUMBER);
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_DisableRxInt
********************************************************************************
*
* Summary:
*  Disable internal Rx interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal Rx interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void PD_microSD_iSPIM_DisableRxInt(void) 
{
    #if(0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED)
        CyIntDisable(PD_microSD_iSPIM_RX_ISR_NUMBER);
    #endif /* (0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED) */
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_SetTxInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void PD_microSD_iSPIM_SetTxInterruptMode(uint8 intSrc) 
{
    PD_microSD_iSPIM_TX_STATUS_MASK_REG = intSrc;
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_SetRxInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void PD_microSD_iSPIM_SetRxInterruptMode(uint8 intSrc) 
{
    PD_microSD_iSPIM_RX_STATUS_MASK_REG  = intSrc;
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ReadTxStatus
********************************************************************************
*
* Summary:
*  Read the Tx status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the Tx status register.
*
* Global variables:
*  PD_microSD_iSPIM_swStatusTx - used to store in software status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the Tx status register for error
*  detection and flow control.
*
* Side Effects:
*  Clear Tx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 PD_microSD_iSPIM_ReadTxStatus(void) 
{
    uint8 tmpStatus;

    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableTxInt();

        tmpStatus = PD_microSD_iSPIM_GET_STATUS_TX(PD_microSD_iSPIM_swStatusTx);
        PD_microSD_iSPIM_swStatusTx = 0u;

        PD_microSD_iSPIM_EnableTxInt();

    #else

        tmpStatus = PD_microSD_iSPIM_TX_STATUS_REG;

    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ReadRxStatus
********************************************************************************
*
* Summary:
*  Read the Rx status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the Rx status register.
*
* Global variables:
*  PD_microSD_iSPIM_swStatusRx - used to store in software Rx status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the Rx status register for error
*  detection and flow control.
*
* Side Effects:
*  Clear Rx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 PD_microSD_iSPIM_ReadRxStatus(void) 
{
    uint8 tmpStatus;

    #if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)
        /* Disable RX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableRxInt();

        tmpStatus = PD_microSD_iSPIM_GET_STATUS_RX(PD_microSD_iSPIM_swStatusRx);
        PD_microSD_iSPIM_swStatusRx = 0u;

        PD_microSD_iSPIM_EnableRxInt();

    #else

        tmpStatus = PD_microSD_iSPIM_RX_STATUS_REG;

    #endif /* (PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_WriteTxData
********************************************************************************
*
* Summary:
*  Write a byte of data to be sent across the SPI.
*
* Parameters:
*  txDataByte: The data value to send across the SPI.
*
* Return:
*  None.
*
* Global variables:
*  PD_microSD_iSPIM_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer, modified every function
*  call if TX Software Buffer is used.
*  PD_microSD_iSPIM_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer.
*  PD_microSD_iSPIM_txBuffer[PD_microSD_iSPIM_TX_BUFFER_SIZE] - used to store
*  data to sending, modified every function call if TX Software Buffer is used.
*
* Theory:
*  Allows the user to transmit any byte of data in a single transfer.
*
* Side Effects:
*  If this function is called again before the previous byte is finished then
*  the next byte will be appended to the transfer with no time between
*  the byte transfers. Clear Tx status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_WriteTxData(uint8 txData) 
{
    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)

        uint8 tempStatus;
        uint8 tmpTxBufferRead;

        /* Block if TX buffer is FULL: don't overwrite */
        do
        {
            tmpTxBufferRead = PD_microSD_iSPIM_txBufferRead;
            if(0u == tmpTxBufferRead)
            {
                tmpTxBufferRead = (PD_microSD_iSPIM_TX_BUFFER_SIZE - 1u);
            }
            else
            {
                tmpTxBufferRead--;
            }

        }while(tmpTxBufferRead == PD_microSD_iSPIM_txBufferWrite);

        /* Disable TX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableTxInt();

        tempStatus = PD_microSD_iSPIM_GET_STATUS_TX(PD_microSD_iSPIM_swStatusTx);
        PD_microSD_iSPIM_swStatusTx = tempStatus;


        if((PD_microSD_iSPIM_txBufferRead == PD_microSD_iSPIM_txBufferWrite) &&
           (0u != (PD_microSD_iSPIM_swStatusTx & PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL)))
        {
            /* Put data element into the TX FIFO */
            CY_SET_REG8(PD_microSD_iSPIM_TXDATA_PTR, txData);
        }
        else
        {
            /* Add to the TX software buffer */
            PD_microSD_iSPIM_txBufferWrite++;
            if(PD_microSD_iSPIM_txBufferWrite >= PD_microSD_iSPIM_TX_BUFFER_SIZE)
            {
                PD_microSD_iSPIM_txBufferWrite = 0u;
            }

            if(PD_microSD_iSPIM_txBufferWrite == PD_microSD_iSPIM_txBufferRead)
            {
                PD_microSD_iSPIM_txBufferRead++;
                if(PD_microSD_iSPIM_txBufferRead >= PD_microSD_iSPIM_TX_BUFFER_SIZE)
                {
                    PD_microSD_iSPIM_txBufferRead = 0u;
                }
                PD_microSD_iSPIM_txBufferFull = 1u;
            }

            PD_microSD_iSPIM_txBuffer[PD_microSD_iSPIM_txBufferWrite] = txData;

            PD_microSD_iSPIM_TX_STATUS_MASK_REG |= PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL;
        }

        PD_microSD_iSPIM_EnableTxInt();

    #else
        /* Wait until TX FIFO has a place */
        while(0u == (PD_microSD_iSPIM_TX_STATUS_REG & PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL))
        {
        }

        /* Put data element into the TX FIFO */
        CY_SET_REG8(PD_microSD_iSPIM_TXDATA_PTR, txData);

    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ReadRxData
********************************************************************************
*
* Summary:
*  Read the next byte of data received across the SPI.
*
* Parameters:
*  None.
*
* Return:
*  The next byte of data read from the FIFO.
*
* Global variables:
*  PD_microSD_iSPIM_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer.
*  PD_microSD_iSPIM_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer, modified every function
*  call if RX Software Buffer is used.
*  PD_microSD_iSPIM_rxBuffer[PD_microSD_iSPIM_RX_BUFFER_SIZE] - used to store
*  received data.
*
* Theory:
*  Allows the user to read a byte of data received.
*
* Side Effects:
*  Will return invalid data if the FIFO is empty. The user should Call
*  GetRxBufferSize() and if it returns a non-zero value then it is safe to call
*  ReadByte() function.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 PD_microSD_iSPIM_ReadRxData(void) 
{
    uint8 rxData;

    #if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)

        /* Disable RX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableRxInt();

        if(PD_microSD_iSPIM_rxBufferRead != PD_microSD_iSPIM_rxBufferWrite)
        {
            if(0u == PD_microSD_iSPIM_rxBufferFull)
            {
                PD_microSD_iSPIM_rxBufferRead++;
                if(PD_microSD_iSPIM_rxBufferRead >= PD_microSD_iSPIM_RX_BUFFER_SIZE)
                {
                    PD_microSD_iSPIM_rxBufferRead = 0u;
                }
            }
            else
            {
                PD_microSD_iSPIM_rxBufferFull = 0u;
            }
        }

        rxData = PD_microSD_iSPIM_rxBuffer[PD_microSD_iSPIM_rxBufferRead];

        PD_microSD_iSPIM_EnableRxInt();

    #else

        rxData = CY_GET_REG8(PD_microSD_iSPIM_RXDATA_PTR);

    #endif /* (PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */

    return(rxData);
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_GetRxBufferSize
********************************************************************************
*
* Summary:
*  Returns the number of bytes/words of data currently held in the RX buffer.
*  If RX Software Buffer not used then function return 0 if FIFO empty or 1 if
*  FIFO not empty. In another case function return size of RX Software Buffer.
*
* Parameters:
*  None.
*
* Return:
*  Integer count of the number of bytes/words in the RX buffer.
*
* Global variables:
*  PD_microSD_iSPIM_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer.
*  PD_microSD_iSPIM_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
uint8 PD_microSD_iSPIM_GetRxBufferSize(void) 
{
    uint8 size;

    #if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)

        /* Disable RX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableRxInt();

        if(PD_microSD_iSPIM_rxBufferRead == PD_microSD_iSPIM_rxBufferWrite)
        {
            size = 0u;
        }
        else if(PD_microSD_iSPIM_rxBufferRead < PD_microSD_iSPIM_rxBufferWrite)
        {
            size = (PD_microSD_iSPIM_rxBufferWrite - PD_microSD_iSPIM_rxBufferRead);
        }
        else
        {
            size = (PD_microSD_iSPIM_RX_BUFFER_SIZE - PD_microSD_iSPIM_rxBufferRead) + PD_microSD_iSPIM_rxBufferWrite;
        }

        PD_microSD_iSPIM_EnableRxInt();

    #else

        /* We can only know if there is data in the RX FIFO */
        size = (0u != (PD_microSD_iSPIM_RX_STATUS_REG & PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY)) ? 1u : 0u;

    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */

    return(size);
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_GetTxBufferSize
********************************************************************************
*
* Summary:
*  Returns the number of bytes/words of data currently held in the TX buffer.
*  If TX Software Buffer not used then function return 0 - if FIFO empty, 1 - if
*  FIFO not full, 4 - if FIFO full. In another case function return size of TX
*  Software Buffer.
*
* Parameters:
*  None.
*
* Return:
*  Integer count of the number of bytes/words in the TX buffer.
*
* Global variables:
*  PD_microSD_iSPIM_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer.
*  PD_microSD_iSPIM_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
uint8  PD_microSD_iSPIM_GetTxBufferSize(void) 
{
    uint8 size;

    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableTxInt();

        if(PD_microSD_iSPIM_txBufferRead == PD_microSD_iSPIM_txBufferWrite)
        {
            size = 0u;
        }
        else if(PD_microSD_iSPIM_txBufferRead < PD_microSD_iSPIM_txBufferWrite)
        {
            size = (PD_microSD_iSPIM_txBufferWrite - PD_microSD_iSPIM_txBufferRead);
        }
        else
        {
            size = (PD_microSD_iSPIM_TX_BUFFER_SIZE - PD_microSD_iSPIM_txBufferRead) + PD_microSD_iSPIM_txBufferWrite;
        }

        PD_microSD_iSPIM_EnableTxInt();

    #else

        size = PD_microSD_iSPIM_TX_STATUS_REG;

        if(0u != (size & PD_microSD_iSPIM_STS_TX_FIFO_EMPTY))
        {
            size = 0u;
        }
        else if(0u != (size & PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL))
        {
            size = 1u;
        }
        else
        {
            size = PD_microSD_iSPIM_FIFO_SIZE;
        }

    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */

    return(size);
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ClearRxBuffer
********************************************************************************
*
* Summary:
*  Clear the RX RAM buffer by setting the read and write pointers both to zero.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  PD_microSD_iSPIM_rxBufferWrite - used for the account of the bytes which
*  have been written down in the RX software buffer, modified every function
*  call - resets to zero.
*  PD_microSD_iSPIM_rxBufferRead - used for the account of the bytes which
*  have been read from the RX software buffer, modified every function call -
*  resets to zero.
*
* Theory:
*  Setting the pointers to zero makes the system believe there is no data to
*  read and writing will resume at address 0 overwriting any data that may have
*  remained in the RAM.
*
* Side Effects:
*  Any received data not read from the RAM buffer will be lost when overwritten.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_ClearRxBuffer(void) 
{
    /* Clear Hardware RX FIFO */
    while(0u !=(PD_microSD_iSPIM_RX_STATUS_REG & PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY))
    {
        (void) CY_GET_REG8(PD_microSD_iSPIM_RXDATA_PTR);
    }

    #if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)
        /* Disable RX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableRxInt();

        PD_microSD_iSPIM_rxBufferFull  = 0u;
        PD_microSD_iSPIM_rxBufferRead  = 0u;
        PD_microSD_iSPIM_rxBufferWrite = 0u;

        PD_microSD_iSPIM_EnableRxInt();
    #endif /* (PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ClearTxBuffer
********************************************************************************
*
* Summary:
*  Clear the TX RAM buffer by setting the read and write pointers both to zero.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  PD_microSD_iSPIM_txBufferWrite - used for the account of the bytes which
*  have been written down in the TX software buffer, modified every function
*  call - resets to zero.
*  PD_microSD_iSPIM_txBufferRead - used for the account of the bytes which
*  have been read from the TX software buffer, modified every function call -
*  resets to zero.
*
* Theory:
*  Setting the pointers to zero makes the system believe there is no data to
*  read and writing will resume at address 0 overwriting any data that may have
*  remained in the RAM.
*
* Side Effects:
*  Any data not yet transmitted from the RAM buffer will be lost when
*  overwritten.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_ClearTxBuffer(void) 
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    /* Clear TX FIFO */
    PD_microSD_iSPIM_AUX_CONTROL_DP0_REG |= ((uint8)  PD_microSD_iSPIM_TX_FIFO_CLR);
    PD_microSD_iSPIM_AUX_CONTROL_DP0_REG &= ((uint8) ~PD_microSD_iSPIM_TX_FIFO_CLR);

    #if(PD_microSD_iSPIM_USE_SECOND_DATAPATH)
        /* Clear TX FIFO for 2nd Datapath */
        PD_microSD_iSPIM_AUX_CONTROL_DP1_REG |= ((uint8)  PD_microSD_iSPIM_TX_FIFO_CLR);
        PD_microSD_iSPIM_AUX_CONTROL_DP1_REG &= ((uint8) ~PD_microSD_iSPIM_TX_FIFO_CLR);
    #endif /* (PD_microSD_iSPIM_USE_SECOND_DATAPATH) */
    CyExitCriticalSection(enableInterrupts);

    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)
        /* Disable TX interrupt to protect global veriables */
        PD_microSD_iSPIM_DisableTxInt();

        PD_microSD_iSPIM_txBufferFull  = 0u;
        PD_microSD_iSPIM_txBufferRead  = 0u;
        PD_microSD_iSPIM_txBufferWrite = 0u;

        /* Buffer is EMPTY: disable TX FIFO NOT FULL interrupt */
        PD_microSD_iSPIM_TX_STATUS_MASK_REG &= ((uint8) ~PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL);

        PD_microSD_iSPIM_EnableTxInt();
    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */
}


#if(0u != PD_microSD_iSPIM_BIDIRECTIONAL_MODE)
    /*******************************************************************************
    * Function Name: PD_microSD_iSPIM_TxEnable
    ********************************************************************************
    *
    * Summary:
    *  If the SPI master is configured to use a single bi-directional pin then this
    *  will set the bi-directional pin to transmit.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void PD_microSD_iSPIM_TxEnable(void) 
    {
        PD_microSD_iSPIM_CONTROL_REG |= PD_microSD_iSPIM_CTRL_TX_SIGNAL_EN;
    }


    /*******************************************************************************
    * Function Name: PD_microSD_iSPIM_TxDisable
    ********************************************************************************
    *
    * Summary:
    *  If the SPI master is configured to use a single bi-directional pin then this
    *  will set the bi-directional pin to receive.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void PD_microSD_iSPIM_TxDisable(void) 
    {
        PD_microSD_iSPIM_CONTROL_REG &= ((uint8) ~PD_microSD_iSPIM_CTRL_TX_SIGNAL_EN);
    }

#endif /* (0u != PD_microSD_iSPIM_BIDIRECTIONAL_MODE) */


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_PutArray
********************************************************************************
*
* Summary:
*  Write available data from ROM/RAM to the TX buffer while space is available
*  in the TX buffer. Keep trying until all data is passed to the TX buffer.
*
* Parameters:
*  *buffer: Pointer to the location in RAM containing the data to send
*  byteCount: The number of bytes to move to the transmit buffer.
*
* Return:
*  None.
*
* Side Effects:
*  Will stay in this routine until all data has been sent.  May get locked in
*  this loop if data is not being initiated by the master if there is not
*  enough room in the TX FIFO.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_PutArray(const uint8 buffer[], uint8 byteCount)
                                                                          
{
    uint8 bufIndex;

    bufIndex = 0u;

    while(byteCount > 0u)
    {
        PD_microSD_iSPIM_WriteTxData(buffer[bufIndex]);
        bufIndex++;
        byteCount--;
    }
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ClearFIFO
********************************************************************************
*
* Summary:
*  Clear the RX and TX FIFO's of all data for a fresh start.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Side Effects:
*  Clear status register of the component.
*
*******************************************************************************/
void PD_microSD_iSPIM_ClearFIFO(void) 
{
    uint8 enableInterrupts;

    /* Clear Hardware RX FIFO */
    while(0u !=(PD_microSD_iSPIM_RX_STATUS_REG & PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY))
    {
        (void) CY_GET_REG8(PD_microSD_iSPIM_RXDATA_PTR);
    }

    enableInterrupts = CyEnterCriticalSection();
    /* Clear TX FIFO */
    PD_microSD_iSPIM_AUX_CONTROL_DP0_REG |= ((uint8)  PD_microSD_iSPIM_TX_FIFO_CLR);
    PD_microSD_iSPIM_AUX_CONTROL_DP0_REG &= ((uint8) ~PD_microSD_iSPIM_TX_FIFO_CLR);

    #if(PD_microSD_iSPIM_USE_SECOND_DATAPATH)
        /* Clear TX FIFO for 2nd Datapath */
        PD_microSD_iSPIM_AUX_CONTROL_DP1_REG |= ((uint8)  PD_microSD_iSPIM_TX_FIFO_CLR);
        PD_microSD_iSPIM_AUX_CONTROL_DP1_REG &= ((uint8) ~PD_microSD_iSPIM_TX_FIFO_CLR);
    #endif /* (PD_microSD_iSPIM_USE_SECOND_DATAPATH) */
    CyExitCriticalSection(enableInterrupts);
}


/* Following functions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects.
*/


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_EnableInt
********************************************************************************
*
* Summary:
*  Enable internal interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Enable the internal interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void PD_microSD_iSPIM_EnableInt(void) 
{
    PD_microSD_iSPIM_EnableRxInt();
    PD_microSD_iSPIM_EnableTxInt();
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_DisableInt
********************************************************************************
*
* Summary:
*  Disable internal interrupt generation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Theory:
*  Disable the internal interrupt output -or- the interrupt component itself.
*
*******************************************************************************/
void PD_microSD_iSPIM_DisableInt(void) 
{
    PD_microSD_iSPIM_DisableTxInt();
    PD_microSD_iSPIM_DisableRxInt();
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_SetInterruptMode
********************************************************************************
*
* Summary:
*  Configure which status bits trigger an interrupt event.
*
* Parameters:
*  intSrc: An or'd combination of the desired status bit masks (defined in the
*  header file).
*
* Return:
*  None.
*
* Theory:
*  Enables the output of specific status bits to the interrupt controller.
*
*******************************************************************************/
void PD_microSD_iSPIM_SetInterruptMode(uint8 intSrc) 
{
    PD_microSD_iSPIM_TX_STATUS_MASK_REG  = (intSrc & ((uint8) ~PD_microSD_iSPIM_STS_SPI_IDLE));
    PD_microSD_iSPIM_RX_STATUS_MASK_REG  =  intSrc;
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_ReadStatus
********************************************************************************
*
* Summary:
*  Read the status register for the component.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the status register.
*
* Global variables:
*  PD_microSD_iSPIM_swStatus - used to store in software status register,
*  modified every function call - resets to zero.
*
* Theory:
*  Allows the user and the API to read the status register for error detection
*  and flow control.
*
* Side Effects:
*  Clear status register of the component.
*
* Reentrant:
*  No.
*
*******************************************************************************/
uint8 PD_microSD_iSPIM_ReadStatus(void) 
{
    uint8 tmpStatus;

    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED || PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)

        PD_microSD_iSPIM_DisableInt();

        tmpStatus  = PD_microSD_iSPIM_GET_STATUS_RX(PD_microSD_iSPIM_swStatusRx);
        tmpStatus |= PD_microSD_iSPIM_GET_STATUS_TX(PD_microSD_iSPIM_swStatusTx);
        tmpStatus &= ((uint8) ~PD_microSD_iSPIM_STS_SPI_IDLE);

        PD_microSD_iSPIM_swStatusTx = 0u;
        PD_microSD_iSPIM_swStatusRx = 0u;

        PD_microSD_iSPIM_EnableInt();

    #else

        tmpStatus  = PD_microSD_iSPIM_RX_STATUS_REG;
        tmpStatus |= PD_microSD_iSPIM_TX_STATUS_REG;
        tmpStatus &= ((uint8) ~PD_microSD_iSPIM_STS_SPI_IDLE);

    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED || PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */

    return(tmpStatus);
}


/* [] END OF FILE */
