/*******************************************************************************
* File Name: PD_microSD_iSPIM.h
* Version 2.50
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the SPI Master Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SPIM_PD_microSD_iSPIM_H)
#define CY_SPIM_PD_microSD_iSPIM_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"

/* Check to see if required defines such as CY_PSOC5A are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5A)
    #error Component SPI_Master_v2_50 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5A) */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define PD_microSD_iSPIM_INTERNAL_CLOCK             (0u)

#if(0u != PD_microSD_iSPIM_INTERNAL_CLOCK)
    #include "PD_microSD_iSPIM_IntClock.h"
#endif /* (0u != PD_microSD_iSPIM_INTERNAL_CLOCK) */

#define PD_microSD_iSPIM_MODE                       (1u)
#define PD_microSD_iSPIM_DATA_WIDTH                 (8u)
#define PD_microSD_iSPIM_MODE_USE_ZERO              (1u)
#define PD_microSD_iSPIM_BIDIRECTIONAL_MODE         (0u)

/* Internal interrupt handling */
#define PD_microSD_iSPIM_TX_BUFFER_SIZE             (4u)
#define PD_microSD_iSPIM_RX_BUFFER_SIZE             (4u)
#define PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED    (0u)
#define PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED    (0u)

#define PD_microSD_iSPIM_SINGLE_REG_SIZE            (8u)
#define PD_microSD_iSPIM_USE_SECOND_DATAPATH        (PD_microSD_iSPIM_DATA_WIDTH > PD_microSD_iSPIM_SINGLE_REG_SIZE)

#define PD_microSD_iSPIM_FIFO_SIZE                  (4u)
#define PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED    ((0u != PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED) && \
                                                     (PD_microSD_iSPIM_TX_BUFFER_SIZE > PD_microSD_iSPIM_FIFO_SIZE))

#define PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED    ((0u != PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED) && \
                                                     (PD_microSD_iSPIM_RX_BUFFER_SIZE > PD_microSD_iSPIM_FIFO_SIZE))


/***************************************
*        Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
    uint8 cntrPeriod;
} PD_microSD_iSPIM_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  PD_microSD_iSPIM_Init(void)                           ;
void  PD_microSD_iSPIM_Enable(void)                         ;
void  PD_microSD_iSPIM_Start(void)                          ;
void  PD_microSD_iSPIM_Stop(void)                           ;

void  PD_microSD_iSPIM_EnableTxInt(void)                    ;
void  PD_microSD_iSPIM_EnableRxInt(void)                    ;
void  PD_microSD_iSPIM_DisableTxInt(void)                   ;
void  PD_microSD_iSPIM_DisableRxInt(void)                   ;

void  PD_microSD_iSPIM_Sleep(void)                          ;
void  PD_microSD_iSPIM_Wakeup(void)                         ;
void  PD_microSD_iSPIM_SaveConfig(void)                     ;
void  PD_microSD_iSPIM_RestoreConfig(void)                  ;

void  PD_microSD_iSPIM_SetTxInterruptMode(uint8 intSrc)     ;
void  PD_microSD_iSPIM_SetRxInterruptMode(uint8 intSrc)     ;
uint8 PD_microSD_iSPIM_ReadTxStatus(void)                   ;
uint8 PD_microSD_iSPIM_ReadRxStatus(void)                   ;
void  PD_microSD_iSPIM_WriteTxData(uint8 txData)  \
                                                            ;
uint8 PD_microSD_iSPIM_ReadRxData(void) \
                                                            ;
uint8 PD_microSD_iSPIM_GetRxBufferSize(void)                ;
uint8 PD_microSD_iSPIM_GetTxBufferSize(void)                ;
void  PD_microSD_iSPIM_ClearRxBuffer(void)                  ;
void  PD_microSD_iSPIM_ClearTxBuffer(void)                  ;
void  PD_microSD_iSPIM_ClearFIFO(void)                              ;
void  PD_microSD_iSPIM_PutArray(const uint8 buffer[], uint8 byteCount) \
                                                            ;

#if(0u != PD_microSD_iSPIM_BIDIRECTIONAL_MODE)
    void  PD_microSD_iSPIM_TxEnable(void)                   ;
    void  PD_microSD_iSPIM_TxDisable(void)                  ;
#endif /* (0u != PD_microSD_iSPIM_BIDIRECTIONAL_MODE) */

CY_ISR_PROTO(PD_microSD_iSPIM_TX_ISR);
CY_ISR_PROTO(PD_microSD_iSPIM_RX_ISR);


/***************************************
*   Variable with external linkage
***************************************/

extern uint8 PD_microSD_iSPIM_initVar;


/***************************************
*           API Constants
***************************************/

#define PD_microSD_iSPIM_TX_ISR_NUMBER     ((uint8) (PD_microSD_iSPIM_TxInternalInterrupt__INTC_NUMBER))
#define PD_microSD_iSPIM_RX_ISR_NUMBER     ((uint8) (PD_microSD_iSPIM_RxInternalInterrupt__INTC_NUMBER))

#define PD_microSD_iSPIM_TX_ISR_PRIORITY   ((uint8) (PD_microSD_iSPIM_TxInternalInterrupt__INTC_PRIOR_NUM))
#define PD_microSD_iSPIM_RX_ISR_PRIORITY   ((uint8) (PD_microSD_iSPIM_RxInternalInterrupt__INTC_PRIOR_NUM))


/***************************************
*    Initial Parameter Constants
***************************************/

#define PD_microSD_iSPIM_INT_ON_SPI_DONE    ((uint8) (0u   << PD_microSD_iSPIM_STS_SPI_DONE_SHIFT))
#define PD_microSD_iSPIM_INT_ON_TX_EMPTY    ((uint8) (0u   << PD_microSD_iSPIM_STS_TX_FIFO_EMPTY_SHIFT))
#define PD_microSD_iSPIM_INT_ON_TX_NOT_FULL ((uint8) (0u << \
                                                                           PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL_SHIFT))
#define PD_microSD_iSPIM_INT_ON_BYTE_COMP   ((uint8) (0u  << PD_microSD_iSPIM_STS_BYTE_COMPLETE_SHIFT))
#define PD_microSD_iSPIM_INT_ON_SPI_IDLE    ((uint8) (0u   << PD_microSD_iSPIM_STS_SPI_IDLE_SHIFT))

/* Disable TX_NOT_FULL if software buffer is used */
#define PD_microSD_iSPIM_INT_ON_TX_NOT_FULL_DEF ((PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) ? \
                                                                        (0u) : (PD_microSD_iSPIM_INT_ON_TX_NOT_FULL))

/* TX interrupt mask */
#define PD_microSD_iSPIM_TX_INIT_INTERRUPTS_MASK    (PD_microSD_iSPIM_INT_ON_SPI_DONE  | \
                                                     PD_microSD_iSPIM_INT_ON_TX_EMPTY  | \
                                                     PD_microSD_iSPIM_INT_ON_TX_NOT_FULL_DEF | \
                                                     PD_microSD_iSPIM_INT_ON_BYTE_COMP | \
                                                     PD_microSD_iSPIM_INT_ON_SPI_IDLE)

#define PD_microSD_iSPIM_INT_ON_RX_FULL         ((uint8) (0u << \
                                                                          PD_microSD_iSPIM_STS_RX_FIFO_FULL_SHIFT))
#define PD_microSD_iSPIM_INT_ON_RX_NOT_EMPTY    ((uint8) (0u << \
                                                                          PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define PD_microSD_iSPIM_INT_ON_RX_OVER         ((uint8) (0u << \
                                                                          PD_microSD_iSPIM_STS_RX_FIFO_OVERRUN_SHIFT))

/* RX interrupt mask */
#define PD_microSD_iSPIM_RX_INIT_INTERRUPTS_MASK    (PD_microSD_iSPIM_INT_ON_RX_FULL      | \
                                                     PD_microSD_iSPIM_INT_ON_RX_NOT_EMPTY | \
                                                     PD_microSD_iSPIM_INT_ON_RX_OVER)
/* Nubmer of bits to receive/transmit */
#define PD_microSD_iSPIM_BITCTR_INIT            (((uint8) (PD_microSD_iSPIM_DATA_WIDTH << 1u)) - 1u)


/***************************************
*             Registers
***************************************/
#if(CY_PSOC3 || CY_PSOC5)
    #define PD_microSD_iSPIM_TXDATA_REG (* (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F0_REG)
    #define PD_microSD_iSPIM_TXDATA_PTR (  (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F0_REG)
    #define PD_microSD_iSPIM_RXDATA_REG (* (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F1_REG)
    #define PD_microSD_iSPIM_RXDATA_PTR (  (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F1_REG)
#else   /* PSOC4 */
    #if(PD_microSD_iSPIM_USE_SECOND_DATAPATH)
        #define PD_microSD_iSPIM_TXDATA_REG (* (reg16 *) \
                                          PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define PD_microSD_iSPIM_TXDATA_PTR (  (reg16 *) \
                                          PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define PD_microSD_iSPIM_RXDATA_REG (* (reg16 *) \
                                          PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
        #define PD_microSD_iSPIM_RXDATA_PTR (  (reg16 *) \
                                          PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
    #else
        #define PD_microSD_iSPIM_TXDATA_REG (* (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F0_REG)
        #define PD_microSD_iSPIM_TXDATA_PTR (  (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F0_REG)
        #define PD_microSD_iSPIM_RXDATA_REG (* (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F1_REG)
        #define PD_microSD_iSPIM_RXDATA_PTR (  (reg8 *) \
                                                PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__F1_REG)
    #endif /* (PD_microSD_iSPIM_USE_SECOND_DATAPATH) */
#endif     /* (CY_PSOC3 || CY_PSOC5) */

#define PD_microSD_iSPIM_AUX_CONTROL_DP0_REG (* (reg8 *) \
                                        PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)
#define PD_microSD_iSPIM_AUX_CONTROL_DP0_PTR (  (reg8 *) \
                                        PD_microSD_iSPIM_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)

#if(PD_microSD_iSPIM_USE_SECOND_DATAPATH)
    #define PD_microSD_iSPIM_AUX_CONTROL_DP1_REG  (* (reg8 *) \
                                        PD_microSD_iSPIM_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
    #define PD_microSD_iSPIM_AUX_CONTROL_DP1_PTR  (  (reg8 *) \
                                        PD_microSD_iSPIM_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
#endif /* (PD_microSD_iSPIM_USE_SECOND_DATAPATH) */

#define PD_microSD_iSPIM_COUNTER_PERIOD_REG     (* (reg8 *) PD_microSD_iSPIM_BSPIM_BitCounter__PERIOD_REG)
#define PD_microSD_iSPIM_COUNTER_PERIOD_PTR     (  (reg8 *) PD_microSD_iSPIM_BSPIM_BitCounter__PERIOD_REG)
#define PD_microSD_iSPIM_COUNTER_CONTROL_REG    (* (reg8 *) PD_microSD_iSPIM_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)
#define PD_microSD_iSPIM_COUNTER_CONTROL_PTR    (  (reg8 *) PD_microSD_iSPIM_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)

#define PD_microSD_iSPIM_TX_STATUS_REG          (* (reg8 *) PD_microSD_iSPIM_BSPIM_TxStsReg__STATUS_REG)
#define PD_microSD_iSPIM_TX_STATUS_PTR          (  (reg8 *) PD_microSD_iSPIM_BSPIM_TxStsReg__STATUS_REG)
#define PD_microSD_iSPIM_RX_STATUS_REG          (* (reg8 *) PD_microSD_iSPIM_BSPIM_RxStsReg__STATUS_REG)
#define PD_microSD_iSPIM_RX_STATUS_PTR          (  (reg8 *) PD_microSD_iSPIM_BSPIM_RxStsReg__STATUS_REG)

#define PD_microSD_iSPIM_CONTROL_REG            (* (reg8 *) \
                                      PD_microSD_iSPIM_BSPIM_BidirMode_CtrlReg__CONTROL_REG)
#define PD_microSD_iSPIM_CONTROL_PTR            (  (reg8 *) \
                                      PD_microSD_iSPIM_BSPIM_BidirMode_CtrlReg__CONTROL_REG)

#define PD_microSD_iSPIM_TX_STATUS_MASK_REG     (* (reg8 *) PD_microSD_iSPIM_BSPIM_TxStsReg__MASK_REG)
#define PD_microSD_iSPIM_TX_STATUS_MASK_PTR     (  (reg8 *) PD_microSD_iSPIM_BSPIM_TxStsReg__MASK_REG)
#define PD_microSD_iSPIM_RX_STATUS_MASK_REG     (* (reg8 *) PD_microSD_iSPIM_BSPIM_RxStsReg__MASK_REG)
#define PD_microSD_iSPIM_RX_STATUS_MASK_PTR     (  (reg8 *) PD_microSD_iSPIM_BSPIM_RxStsReg__MASK_REG)

#define PD_microSD_iSPIM_TX_STATUS_ACTL_REG     (* (reg8 *) PD_microSD_iSPIM_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define PD_microSD_iSPIM_TX_STATUS_ACTL_PTR     (  (reg8 *) PD_microSD_iSPIM_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define PD_microSD_iSPIM_RX_STATUS_ACTL_REG     (* (reg8 *) PD_microSD_iSPIM_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)
#define PD_microSD_iSPIM_RX_STATUS_ACTL_PTR     (  (reg8 *) PD_microSD_iSPIM_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)

#if(PD_microSD_iSPIM_USE_SECOND_DATAPATH)
    #define PD_microSD_iSPIM_AUX_CONTROLDP1     (PD_microSD_iSPIM_AUX_CONTROL_DP1_REG)
#endif /* (PD_microSD_iSPIM_USE_SECOND_DATAPATH) */


/***************************************
*       Register Constants
***************************************/

/* Status Register Definitions */
#define PD_microSD_iSPIM_STS_SPI_DONE_SHIFT             (0x00u)
#define PD_microSD_iSPIM_STS_TX_FIFO_EMPTY_SHIFT        (0x01u)
#define PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL_SHIFT     (0x02u)
#define PD_microSD_iSPIM_STS_BYTE_COMPLETE_SHIFT        (0x03u)
#define PD_microSD_iSPIM_STS_SPI_IDLE_SHIFT             (0x04u)
#define PD_microSD_iSPIM_STS_RX_FIFO_FULL_SHIFT         (0x04u)
#define PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY_SHIFT    (0x05u)
#define PD_microSD_iSPIM_STS_RX_FIFO_OVERRUN_SHIFT      (0x06u)

#define PD_microSD_iSPIM_STS_SPI_DONE           ((uint8) (0x01u << PD_microSD_iSPIM_STS_SPI_DONE_SHIFT))
#define PD_microSD_iSPIM_STS_TX_FIFO_EMPTY      ((uint8) (0x01u << PD_microSD_iSPIM_STS_TX_FIFO_EMPTY_SHIFT))
#define PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL   ((uint8) (0x01u << PD_microSD_iSPIM_STS_TX_FIFO_NOT_FULL_SHIFT))
#define PD_microSD_iSPIM_STS_BYTE_COMPLETE      ((uint8) (0x01u << PD_microSD_iSPIM_STS_BYTE_COMPLETE_SHIFT))
#define PD_microSD_iSPIM_STS_SPI_IDLE           ((uint8) (0x01u << PD_microSD_iSPIM_STS_SPI_IDLE_SHIFT))
#define PD_microSD_iSPIM_STS_RX_FIFO_FULL       ((uint8) (0x01u << PD_microSD_iSPIM_STS_RX_FIFO_FULL_SHIFT))
#define PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY  ((uint8) (0x01u << PD_microSD_iSPIM_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define PD_microSD_iSPIM_STS_RX_FIFO_OVERRUN    ((uint8) (0x01u << PD_microSD_iSPIM_STS_RX_FIFO_OVERRUN_SHIFT))

/* TX and RX masks for clear on read bits */
#define PD_microSD_iSPIM_TX_STS_CLR_ON_RD_BYTES_MASK    (0x09u)
#define PD_microSD_iSPIM_RX_STS_CLR_ON_RD_BYTES_MASK    (0x40u)

/* StatusI Register Interrupt Enable Control Bits */
/* As defined by the Register map for the AUX Control Register */
#define PD_microSD_iSPIM_INT_ENABLE     (0x10u) /* Enable interrupt from statusi */
#define PD_microSD_iSPIM_TX_FIFO_CLR    (0x01u) /* F0 - TX FIFO */
#define PD_microSD_iSPIM_RX_FIFO_CLR    (0x02u) /* F1 - RX FIFO */
#define PD_microSD_iSPIM_FIFO_CLR       (PD_microSD_iSPIM_TX_FIFO_CLR | PD_microSD_iSPIM_RX_FIFO_CLR)

/* Bit Counter (7-bit) Control Register Bit Definitions */
/* As defined by the Register map for the AUX Control Register */
#define PD_microSD_iSPIM_CNTR_ENABLE    (0x20u) /* Enable CNT7 */

/* Bi-Directional mode control bit */
#define PD_microSD_iSPIM_CTRL_TX_SIGNAL_EN  (0x01u)

/* Datapath Auxillary Control Register definitions */
#define PD_microSD_iSPIM_AUX_CTRL_FIFO0_CLR         (0x01u)
#define PD_microSD_iSPIM_AUX_CTRL_FIFO1_CLR         (0x02u)
#define PD_microSD_iSPIM_AUX_CTRL_FIFO0_LVL         (0x04u)
#define PD_microSD_iSPIM_AUX_CTRL_FIFO1_LVL         (0x08u)
#define PD_microSD_iSPIM_STATUS_ACTL_INT_EN_MASK    (0x10u)

/* Component disabled */
#define PD_microSD_iSPIM_DISABLED   (0u)


/***************************************
*       Macros
***************************************/

/* Returns true if componentn enabled */
#define PD_microSD_iSPIM_IS_ENABLED (0u != (PD_microSD_iSPIM_TX_STATUS_ACTL_REG & PD_microSD_iSPIM_INT_ENABLE))

/* Retuns TX status register */
#define PD_microSD_iSPIM_GET_STATUS_TX(swTxSts) ( (uint8)(PD_microSD_iSPIM_TX_STATUS_REG | \
                                                          ((swTxSts) & PD_microSD_iSPIM_TX_STS_CLR_ON_RD_BYTES_MASK)) )
/* Retuns RX status register */
#define PD_microSD_iSPIM_GET_STATUS_RX(swRxSts) ( (uint8)(PD_microSD_iSPIM_RX_STATUS_REG | \
                                                          ((swRxSts) & PD_microSD_iSPIM_RX_STS_CLR_ON_RD_BYTES_MASK)) )


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define PD_microSD_iSPIM_WriteByte   PD_microSD_iSPIM_WriteTxData
#define PD_microSD_iSPIM_ReadByte    PD_microSD_iSPIM_ReadRxData
void  PD_microSD_iSPIM_SetInterruptMode(uint8 intSrc)       ;
uint8 PD_microSD_iSPIM_ReadStatus(void)                     ;
void  PD_microSD_iSPIM_EnableInt(void)                      ;
void  PD_microSD_iSPIM_DisableInt(void)                     ;

#define PD_microSD_iSPIM_TXDATA                 (PD_microSD_iSPIM_TXDATA_REG)
#define PD_microSD_iSPIM_RXDATA                 (PD_microSD_iSPIM_RXDATA_REG)
#define PD_microSD_iSPIM_AUX_CONTROLDP0         (PD_microSD_iSPIM_AUX_CONTROL_DP0_REG)
#define PD_microSD_iSPIM_TXBUFFERREAD           (PD_microSD_iSPIM_txBufferRead)
#define PD_microSD_iSPIM_TXBUFFERWRITE          (PD_microSD_iSPIM_txBufferWrite)
#define PD_microSD_iSPIM_RXBUFFERREAD           (PD_microSD_iSPIM_rxBufferRead)
#define PD_microSD_iSPIM_RXBUFFERWRITE          (PD_microSD_iSPIM_rxBufferWrite)

#define PD_microSD_iSPIM_COUNTER_PERIOD         (PD_microSD_iSPIM_COUNTER_PERIOD_REG)
#define PD_microSD_iSPIM_COUNTER_CONTROL        (PD_microSD_iSPIM_COUNTER_CONTROL_REG)
#define PD_microSD_iSPIM_STATUS                 (PD_microSD_iSPIM_TX_STATUS_REG)
#define PD_microSD_iSPIM_CONTROL                (PD_microSD_iSPIM_CONTROL_REG)
#define PD_microSD_iSPIM_STATUS_MASK            (PD_microSD_iSPIM_TX_STATUS_MASK_REG)
#define PD_microSD_iSPIM_STATUS_ACTL            (PD_microSD_iSPIM_TX_STATUS_ACTL_REG)

#define PD_microSD_iSPIM_INIT_INTERRUPTS_MASK  (PD_microSD_iSPIM_INT_ON_SPI_DONE     | \
                                                PD_microSD_iSPIM_INT_ON_TX_EMPTY     | \
                                                PD_microSD_iSPIM_INT_ON_TX_NOT_FULL_DEF  | \
                                                PD_microSD_iSPIM_INT_ON_RX_FULL      | \
                                                PD_microSD_iSPIM_INT_ON_RX_NOT_EMPTY | \
                                                PD_microSD_iSPIM_INT_ON_RX_OVER      | \
                                                PD_microSD_iSPIM_INT_ON_BYTE_COMP)
                                                
#define PD_microSD_iSPIM_DataWidth                  (PD_microSD_iSPIM_DATA_WIDTH)
#define PD_microSD_iSPIM_InternalClockUsed          (PD_microSD_iSPIM_INTERNAL_CLOCK)
#define PD_microSD_iSPIM_InternalTxInterruptEnabled (PD_microSD_iSPIM_INTERNAL_TX_INT_ENABLED)
#define PD_microSD_iSPIM_InternalRxInterruptEnabled (PD_microSD_iSPIM_INTERNAL_RX_INT_ENABLED)
#define PD_microSD_iSPIM_ModeUseZero                (PD_microSD_iSPIM_MODE_USE_ZERO)
#define PD_microSD_iSPIM_BidirectionalMode          (PD_microSD_iSPIM_BIDIRECTIONAL_MODE)
#define PD_microSD_iSPIM_Mode                       (PD_microSD_iSPIM_MODE)
#define PD_microSD_iSPIM_DATAWIDHT                  (PD_microSD_iSPIM_DATA_WIDTH)
#define PD_microSD_iSPIM_InternalInterruptEnabled   (0u)

#define PD_microSD_iSPIM_TXBUFFERSIZE   (PD_microSD_iSPIM_TX_BUFFER_SIZE)
#define PD_microSD_iSPIM_RXBUFFERSIZE   (PD_microSD_iSPIM_RX_BUFFER_SIZE)

#define PD_microSD_iSPIM_TXBUFFER       PD_microSD_iSPIM_txBuffer
#define PD_microSD_iSPIM_RXBUFFER       PD_microSD_iSPIM_rxBuffer

#endif /* (CY_SPIM_PD_microSD_iSPIM_H) */


/* [] END OF FILE */
