/*******************************************************************************
* File Name: PD_microSD_iSPIM_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PD_microSD_iSPIM_PVT.h"

static PD_microSD_iSPIM_BACKUP_STRUCT PD_microSD_iSPIM_backup =
{
    PD_microSD_iSPIM_DISABLED,
    PD_microSD_iSPIM_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void PD_microSD_iSPIM_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void PD_microSD_iSPIM_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PD_microSD_iSPIM_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_Sleep(void) 
{
    /* Save components enable state */
    PD_microSD_iSPIM_backup.enableState = ((uint8) PD_microSD_iSPIM_IS_ENABLED);

    PD_microSD_iSPIM_Stop();
}


/*******************************************************************************
* Function Name: PD_microSD_iSPIM_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PD_microSD_iSPIM_backup - used when non-retention registers are restored.
*  PD_microSD_iSPIM_txBufferWrite - modified every function call - resets to
*  zero.
*  PD_microSD_iSPIM_txBufferRead - modified every function call - resets to
*  zero.
*  PD_microSD_iSPIM_rxBufferWrite - modified every function call - resets to
*  zero.
*  PD_microSD_iSPIM_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PD_microSD_iSPIM_Wakeup(void) 
{
    #if(PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED)
        PD_microSD_iSPIM_rxBufferFull  = 0u;
        PD_microSD_iSPIM_rxBufferRead  = 0u;
        PD_microSD_iSPIM_rxBufferWrite = 0u;
    #endif /* (PD_microSD_iSPIM_RX_SOFTWARE_BUF_ENABLED) */

    #if(PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED)
        PD_microSD_iSPIM_txBufferFull  = 0u;
        PD_microSD_iSPIM_txBufferRead  = 0u;
        PD_microSD_iSPIM_txBufferWrite = 0u;
    #endif /* (PD_microSD_iSPIM_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    PD_microSD_iSPIM_ClearFIFO();

    /* Restore components block enable state */
    if(0u != PD_microSD_iSPIM_backup.enableState)
    {
        PD_microSD_iSPIM_Enable();
    }
}


/* [] END OF FILE */
